@@ -21,20 +21,20 @@ struct Treaty;
 struct Clause;
 struct ai_data;
 
-void ai_diplomacy_begin_new_phase(struct player *pplayer);
-void dai_diplomacy_actions(struct player *pplayer);
+void dai_diplomacy_begin_new_phase(struct ai_type *ait, struct player *pplayer);
+void dai_diplomacy_actions(struct ai_type *ait, struct player *pplayer);
 
-void dai_treaty_evaluate(struct player *pplayer, struct player *aplayer,
-			 struct Treaty *ptreaty);
-void dai_treaty_accepted(struct player *pplayer, struct player *aplayer, 
-			 struct Treaty *ptreaty);
+void dai_treaty_evaluate(struct ai_type *ait, struct player *pplayer,
+                         struct player *aplayer, struct Treaty *ptreaty);
+void dai_treaty_accepted(struct ai_type *ait, struct player *pplayer,
+                         struct player *aplayer, struct Treaty *ptreaty);
 
-void dai_incident(enum incident_type type, struct player *violator,
-		  struct player *victim);
+void dai_incident(struct ai_type *ait, enum incident_type type,
+                  struct player *violator, struct player *victim);
 
-bool ai_on_war_footing(struct player *pplayer);
+bool dai_on_war_footing(struct ai_type *ait, struct player *pplayer);
 
-void dai_diplomacy_first_contact(struct player *pplayer,
-				 struct player *aplayer);
+void dai_diplomacy_first_contact(struct ai_type *ait, struct player *pplayer,
+                                 struct player *aplayer);
 
-#endif
+#endif /* FC__ADVDIPLOMACY_H */
