@@ -15,10 +15,11 @@
 
 #include "fc_types.h"
 
-void domestic_advisor_choose_build(struct player *pplayer, struct city *pcity,
-				   struct adv_choice *choice);
+void domestic_advisor_choose_build(struct ai_type *ait, struct player *pplayer,
+                                   struct city *pcity,
+                                   struct adv_choice *choice);
 
-void dai_wonder_city_distance(struct player *pplayer, 
+void dai_wonder_city_distance(struct ai_type *ait, struct player *pplayer, 
                               struct adv_data *adv);
 
 #endif  /* FC__ADVDOMESTIC_H */
