@@ -715,14 +715,23 @@ static void contemplate_terrain_improvements(struct ai_type *ait,
   }
   want = MAX(want, 0);
 
-  CITY_LOG(LOG_DEBUG, pcity, "wants %s with want %d to do %s at (%d,%d), "
-           "we have %d workers and %d cities on the continent",
-	   utype_rule_name(utype),
-	   want,
-	   get_activity_text(best_act),
-	   TILE_XY(best_tile),
-           ai->stats.workers[place], 
-           ai->stats.cities[place]);
+  if (place >= 0) {
+    CITY_LOG(LOG_DEBUG, pcity, "wants %s with want %d to do %s at (%d,%d), "
+             "we have %d workers and %d cities on the continent",
+             utype_rule_name(utype),
+             want,
+             get_activity_text(best_act),
+             TILE_XY(best_tile),
+             ai->stats.workers[place], 
+             ai->stats.cities[place]);
+  } else {
+    CITY_LOG(LOG_DEBUG, pcity, "wants %s with want %d to do %s at (%d,%d)",
+             utype_rule_name(utype),
+             want,
+             get_activity_text(best_act),
+             TILE_XY(best_tile));
+  }
+
   fc_assert(want >= 0);
 
   city_data->settler_want = want;
@@ -765,6 +774,11 @@ void dai_manage_cities(struct ai_type *ait, struct player *pplayer)
     military_advisor_choose_build(ait, pplayer, pcity, &city_data->choice);
     TIMING_LOG(AIT_CITY_MILITARY, TIMER_STOP);
     if (dai_on_war_footing(ait, pplayer) && city_data->choice.want > 0) {
+      city_data->settler_want = 0;
+      city_data->founder_want = 0;
+      city_data->founder_turn = game.info.turn; /* Do not consider zero we set here
+                                                 * valid value, if real want is needed.
+                                                 * Recalculate immediately in such situation. */
       continue; /* Go, soldiers! */
     }
     /* Will record its findings in pcity->settler_want */ 
@@ -777,6 +791,8 @@ void dai_manage_cities(struct ai_type *ait, struct player *pplayer)
       /* Will record its findings in pcity->founder_want */ 
       contemplate_new_city(ait, pcity);
       /* Avoid recalculating all the time.. */
+      /* This means AI is not very opportunistic if there happens to open up spot for
+       * a new city. */
       city_data->founder_turn = 
         game.info.turn + fc_rand(AI_CITY_RECALC_SPEED) + AI_CITY_RECALC_SPEED;
     } else if (pcity->server.debug) {
