@@ -17,9 +17,10 @@
 
 #include "fc_types.h"
 
-void ai_hunter_choice(struct player *pplayer, struct city *pcity,
-                      struct adv_choice *choice);
-bool ai_hunter_qualify(struct player *pplayer, struct unit *punit);
-int ai_hunter_manage(struct player *pplayer, struct unit *punit);
+void dai_hunter_choice(struct ai_type *ait, struct player *pplayer,
+                       struct city *pcity, struct adv_choice *choice);
+bool dai_hunter_qualify(struct player *pplayer, struct unit *punit);
+int dai_hunter_manage(struct ai_type *ait, struct player *pplayer,
+                      struct unit *punit);
 
 #endif /* FC__AIHUNT_H */
