@@ -1183,7 +1183,8 @@ void dai_auto_settler_cont(struct ai_type *ait, struct player *pplayer,
 **************************************************************************/
 void dai_auto_settler_reset(struct ai_type *ait, struct player *pplayer)
 {
-  struct ai_plr *ai = dai_plr_data_get(ait, pplayer, NULL);
+  bool close;
+  struct ai_plr *ai = dai_plr_data_get(ait, pplayer, &close);
 
   fc_assert_ret(ai != NULL);
   fc_assert_ret(ai->settler != NULL);
@@ -1202,6 +1203,10 @@ void dai_auto_settler_reset(struct ai_type *ait, struct player *pplayer)
 #endif /* DEBUG */
 
   tile_data_cache_hash_clear(ai->settler->tdc_hash);
+
+  if (close) {
+    dai_data_phase_finished(ait, pplayer);
+  }
 }
 
 /**************************************************************************
