@@ -178,11 +178,12 @@ version_check ()
   }
 
   # The following line is carefully crafted sed magic
-  pkg_version=`$PACKAGE --version 2>&1|grep -v " line " |head -n 1|sed 's/([^)]*)//g;s/^[a-zA-Z\.\ \-]*//;s/ .*$//'`
+  pkg_version=`$PACKAGE --version 2>&1|grep -a -v " line " |head -n 1|sed 's/([^)]*)//g;s/^[a-zA-Z\.\ \-]*//;s/ .*$//'`
   debug "pkg_version $pkg_version"
   pkg_major=`echo $pkg_version | cut -d. -f1`
   pkg_minor=`echo $pkg_version | sed s/[-,a-z,A-Z].*// | cut -d. -f2`
   pkg_micro=`echo $pkg_version | sed s/[-,a-z,A-Z].*// | cut -d. -f3`
+  [ -z "$pkg_major" ] && pkg_major=0
   [ -z "$pkg_minor" ] && pkg_minor=0
   [ -z "$pkg_micro" ] && pkg_micro=0
 
@@ -283,6 +284,12 @@ $LIBTOOLIZE -f || {
   echo "$LIBTOOLIZE failed"
   exit 1
 }
+echo "+ running $ACLOCAL for libtool installed files..."
+$ACLOCAL -I m4 -I dependencies/m4 $ACLOCAL_FLAGS || {
+  echo
+  echo "$ACLOCAL failed on libtool files run"
+  exit 1
+}
 echo "+ running $AUTOCONF ... "
 $AUTOCONF || {
   echo
