@@ -11,8 +11,12 @@
    GNU General Public License for more details.
 ***********************************************************************/
 
-#ifndef FC__CLIENT_AGENTS_CITY_MANAGEMENT_H
-#define FC__CLIENT_AGENTS_CITY_MANAGEMENT_H
+#ifndef FC__CMA_CORE_H
+#define FC__CMA_CORE_H
+
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
 
 /*
  * CM stands for citizen management.
@@ -61,4 +65,8 @@ bool cma_get_parameter(enum attr_city attr, int city_id,
 void cma_set_parameter(enum attr_city attr, int city_id,
 		       const struct cm_parameter *parameter);
 
-#endif
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+#endif /* FC__CMA_CORE_H */
