@@ -42,8 +42,7 @@ struct attr_key {
   int key, id, x, y;
 };
 
-static genhash_val_t attr_key_val(const struct attr_key *pkey,
-                                  size_t num_buckets);
+static genhash_val_t attr_key_val(const struct attr_key *pkey);
 static bool attr_key_comp(const struct attr_key *pkey1,
                           const struct attr_key *pkey2);
 static struct attr_key *attr_key_dup(const struct attr_key *pkey);
@@ -72,11 +71,9 @@ static struct attribute_hash *attribute_hash = NULL;
 /****************************************************************************
   Hash function for attribute_hash.
 ****************************************************************************/
-static genhash_val_t attr_key_val(const struct attr_key *pkey,
-                                  size_t num_buckets)
+static genhash_val_t attr_key_val(const struct attr_key *pkey)
 {
-  return (((genhash_val_t) pkey->id ^ pkey->x ^ pkey->y ^ pkey->key)
-          % num_buckets);
+  return (genhash_val_t) pkey->id ^ pkey->x ^ pkey->y ^ pkey->key;
 }
 
 /****************************************************************************
@@ -272,8 +269,7 @@ static enum attribute_serial unserialize_hash(struct attribute_hash *hash,
     int value_length;
     struct data_out dout;
 
-    dio_get_uint32(&din, &value_length);
-    if (din.too_short) {
+    if (!dio_get_uint32(&din, &value_length)) {
       log_verbose("attribute.c unserialize_hash() "
                   "uint32 value_length dio_input_too_short");
       return A_SERIAL_FAIL;
@@ -282,12 +278,10 @@ static enum attribute_serial unserialize_hash(struct attribute_hash *hash,
                   "uint32 %lu value_length", (long unsigned) value_length);
 
     /* next 12 bytes */
-    dio_get_uint32(&din, &key.key);
-    dio_get_uint32(&din, &key.id);
-    dio_get_sint16(&din, &key.x);
-    dio_get_sint16(&din, &key.y);
-
-    if (din.too_short) {
+    if (!dio_get_uint32(&din, &key.key)
+        || !dio_get_uint32(&din, &key.id)
+        || !dio_get_sint16(&din, &key.x)
+        || !dio_get_sint16(&din, &key.y)) {
       log_verbose("attribute.c unserialize_hash() "
                   "uint32 key dio_input_too_short");
       return A_SERIAL_FAIL;
