@@ -174,13 +174,18 @@ void output_window_event(const char *plain_text,
 /****************************************************************************
   Standard welcome message.
 ****************************************************************************/
-void chat_welcome_message(void)
+void chat_welcome_message(bool gui_has_copying_mitem)
 {
   output_window_append(ftc_any, _("Freeciv is free software and you are "
                                   "welcome to distribute copies of it "
                                   "under certain conditions;"));
-  output_window_append(ftc_any, _("See the \"Copying\" item on the "
-                                  "Help menu."));
+  if (gui_has_copying_mitem) {
+    output_window_append(ftc_any, _("See the \"Copying\" item on the "
+                                    "Help menu."));
+  } else {
+    output_window_append(ftc_any, _("See COPYING file distributed with "
+                                    "this program."));
+  }
   output_window_append(ftc_any, _("Now ... Go give 'em hell!"));
 }
 
