@@ -16,8 +16,10 @@
 
 #include <gtk/gtk.h>
 
+/* common */
 #include "fc_types.h"
 
+/* client/agents */
 #include "cma_core.h"
 
 enum cma_refresh {
@@ -38,9 +40,9 @@ struct cma_dialog {
   GtkWidget *active_label;
   GtkWidget *active_image;
   GtkWidget *active_command;
-  GtkAdjustment *minimal_surplus[O_LAST];
+  GtkWidget *minimal_surplus[O_LAST];
   GtkWidget *happy_button;
-  GtkAdjustment *factor[O_LAST + 1];
+  GtkWidget *factor[O_LAST + 1];
   GtkTreeSelection *selection;
   GtkListStore *store;
   int id;			/* needed to pass a preset_index */
@@ -48,8 +50,8 @@ struct cma_dialog {
 
 void cma_fe_init(void);
 void cma_fe_done(void);
-struct cma_dialog *create_cma_dialog(struct city *pcity);
+struct cma_dialog *create_cma_dialog(struct city *pcity, bool tiny);
 void close_cma_dialog(struct city *pcity);
 void refresh_cma_dialog(struct city *pcity, enum cma_refresh refresh);
 
-#endif
+#endif /* FC__GTK_CMA_H */
