@@ -692,7 +692,8 @@ static struct Diplomacy_dialog *create_diplomacy_dialog(struct player *plr0,
 
   /* Our nation. */
   label = gtk_label_new(NULL);
-  gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);
+  gtk_widget_set_halign(label, GTK_ALIGN_CENTER);
+  gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
   buf = g_strdup_printf("<span size=\"large\"><u>%s</u></span>",
                         nation_plural_for_player(plr0));
   gtk_label_set_markup(GTK_LABEL(label), buf);
@@ -712,7 +713,8 @@ static struct Diplomacy_dialog *create_diplomacy_dialog(struct player *plr0,
   /* Our name. */
   label = gtk_label_new(NULL);
   gtk_widget_set_hexpand(label, TRUE);
-  gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);
+  gtk_widget_set_halign(label, GTK_ALIGN_CENTER);
+  gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
   buf = g_strdup_printf("<span size=\"large\" weight=\"bold\">%s</span>",
                         ruler_title_for_player(plr0, plr_buf, sizeof(plr_buf)));
   gtk_label_set_markup(GTK_LABEL(label), buf);
@@ -775,7 +777,8 @@ static struct Diplomacy_dialog *create_diplomacy_dialog(struct player *plr0,
 
   /* Their nation. */
   label = gtk_label_new(NULL);
-  gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);
+  gtk_widget_set_halign(label, GTK_ALIGN_CENTER);
+  gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
   buf = g_strdup_printf("<span size=\"large\"><u>%s</u></span>",
                         nation_plural_for_player(plr1));
   gtk_label_set_markup(GTK_LABEL(label), buf);
@@ -795,7 +798,8 @@ static struct Diplomacy_dialog *create_diplomacy_dialog(struct player *plr0,
   /* Their name. */
   label = gtk_label_new(NULL);
   gtk_widget_set_hexpand(label, TRUE);
-  gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);
+  gtk_widget_set_halign(label, GTK_ALIGN_CENTER);
+  gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
   buf = g_strdup_printf("<span size=\"large\" weight=\"bold\">%s</span>",
                         ruler_title_for_player(plr1, plr_buf, sizeof(plr_buf)));
   gtk_label_set_markup(GTK_LABEL(label), buf);
