@@ -43,7 +43,7 @@
 #include "options.h"
 #include "text.h"
 
-/* clien/gui-gtk-2.0 */
+/* clien/gui-gtk-3.0 */
 #include "plrdlg.h"
 #include "dialogs.h"
 #include "gui_main.h"
@@ -60,6 +60,7 @@ static GtkWidget *all_toggle;
 static GtkListStore *store;
 static GtkTreeSelection *selection;
 struct tile *original_tile;
+static bool gotodlg_updating = FALSE;
 
 static void update_goto_dialog(GtkToggleButton *button);
 static void update_source_label(void);
@@ -158,7 +159,7 @@ static void create_goto_dialog(void)
   source = gtk_label_new("" /* filled in later */);
   gtk_label_set_line_wrap(GTK_LABEL(source), TRUE);
   gtk_label_set_justify(GTK_LABEL(source), GTK_JUSTIFY_CENTER);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dshell)->vbox),
+  gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dshell))),
         source, FALSE, FALSE, 0);
 
   label = g_object_new(GTK_TYPE_LABEL,
@@ -169,10 +170,13 @@ static void create_goto_dialog(void)
     NULL);
   frame = gtk_frame_new("");
   gtk_frame_set_label_widget(GTK_FRAME(frame), label);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dshell)->vbox),
+  gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dshell))),
         frame, TRUE, TRUE, 0);
 
-  vbox = gtk_vbox_new(FALSE, 6);
+  vbox = gtk_grid_new();
+  gtk_orientable_set_orientation(GTK_ORIENTABLE(vbox),
+                                 GTK_ORIENTATION_VERTICAL);
+  gtk_grid_set_row_spacing(GTK_GRID(vbox), 6);
   gtk_container_add(GTK_CONTAINER(frame), vbox);
 
   store = gtk_list_store_new(GD_COL_NUM, G_TYPE_INT, G_TYPE_STRING,
@@ -181,6 +185,8 @@ static void create_goto_dialog(void)
     GD_COL_CITY_NAME, GTK_SORT_ASCENDING);
 
   view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
+  gtk_widget_set_hexpand(view, TRUE);
+  gtk_widget_set_vexpand(view, TRUE);
   g_object_unref(store);
   selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(view), TRUE);
@@ -225,21 +231,19 @@ static void create_goto_dialog(void)
   gtk_container_add(GTK_CONTAINER(sw), view);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
     GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
-  gtk_widget_set_size_request(sw, -1, 200);
+  gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW(sw), 200);
 
-  gtk_box_pack_start(GTK_BOX(vbox), sw, TRUE, TRUE, 0);
+  gtk_container_add(GTK_CONTAINER(vbox), sw);
 
   all_toggle = gtk_check_button_new_with_mnemonic(_("Show _All Cities"));
-  gtk_box_pack_start(GTK_BOX(vbox), all_toggle, FALSE, FALSE, 0);
+  gtk_container_add(GTK_CONTAINER(vbox), all_toggle);
 
   g_signal_connect(all_toggle, "toggled", G_CALLBACK(update_goto_dialog), NULL);
 
   g_signal_connect(selection, "changed",
     G_CALLBACK(goto_selection_callback), NULL);
 
-  gtk_widget_show_all(GTK_DIALOG(dshell)->vbox);
-  gtk_widget_show_all(GTK_DIALOG(dshell)->action_area);
-
+  gtk_widget_show_all(dshell);
 
   original_tile = get_center_tile_mapcanvas();
 
@@ -428,13 +432,15 @@ static void update_goto_dialog(GtkToggleButton *button)
 {
   bool nonempty = FALSE;
 
-  gtk_list_store_clear(store);
-
   if (!client_has_player()) {
     /* Case global observer. */
     return;
   }
 
+  gotodlg_updating = TRUE;
+
+  gtk_list_store_clear(store);
+
   if (gtk_toggle_button_get_active(button)) {
     players_iterate(pplayer) {
       nonempty |= list_store_append_player_cities(store, pplayer);
@@ -442,6 +448,9 @@ static void update_goto_dialog(GtkToggleButton *button)
   } else {
     nonempty |= list_store_append_player_cities(store, client_player());
   }
+
+  gotodlg_updating = FALSE;
+
   refresh_airlift_column();
 
   if (!nonempty) {
@@ -509,7 +518,13 @@ static void refresh_airlift_button(void)
 static void goto_selection_callback(GtkTreeSelection *selection,
                                     gpointer data)
 {
-  struct city *pdestcity = get_selected_city();
+  struct city *pdestcity;
+
+  if (gotodlg_updating) {
+    return;
+  }
+
+  pdestcity = get_selected_city();
 
   if (NULL != pdestcity) {
     center_tile_mapcanvas(city_tile(pdestcity));
