@@ -1011,8 +1011,47 @@ void gui_update_font(const char *font_name, const char *font_value)
 {
   char *str;
   GtkCssProvider *provider;
+  PangoFontDescription *desc;
+  int size;
+  const char *fam;
+  const char *style;
+  const char *weight;
 
-  str = g_strdup_printf("#Freeciv #%s { font: %s;}", font_name, font_value);
+  desc = pango_font_description_from_string(font_value);
+
+  if (desc == NULL) {
+    return;
+  }
+
+  fam = pango_font_description_get_family(desc);
+
+  if (fam == NULL) {
+    return;
+  }
+
+  if (pango_font_description_get_style(desc) == PANGO_STYLE_ITALIC) {
+    style = "\n font-style: italic;";
+  } else {
+    style = "";
+  }
+
+  if (pango_font_description_get_weight(desc) >= 700) {
+    weight = "\n font-weight: bold;";
+  } else {
+    weight = "";
+  }
+
+  size = pango_font_description_get_size(desc);
+
+  if (size != 0) {
+    str = g_strdup_printf("#Freeciv #%s { font-family: %s; font-size: %dpx;%s%s}",
+                          font_name, fam, size / PANGO_SCALE, style, weight);
+  } else {
+    str = g_strdup_printf("#Freeciv #%s { font-family: %s;%s%s}",
+                          font_name, fam, style, weight);
+  }
+
+  pango_font_description_free(desc);
 
   provider = gtk_css_provider_new();
   gtk_css_provider_load_from_data(GTK_CSS_PROVIDER(provider),
