@@ -23,6 +23,7 @@ extern "C" {
 }
 
 //Qt
+#include <QEvent>
 #include <QTextBrowser>
 #include <QLineEdit>
 #include <QCheckBox>
@@ -60,4 +61,12 @@ private:
 
 };
 
+class version_message_event : public QEvent
+{
+  QString message;
+public:
+  explicit version_message_event(const QString &message);
+  QString get_message() const { return message; }
+};
+
 #endif                        /* FC__CHATLINE_H */
