@@ -437,7 +437,9 @@ void races_dialog::nation_selected(const QItemSelection &selected,
   helptext_nation(buf, sizeof(buf), nation_by_number(selected_nation), NULL);
   description->setText(buf);
   leader_name->clear();
-  leader_name->addItem(client.conn.playing->name, true);
+  if (client.conn.playing == tplayer) {
+    leader_name->addItem(client.conn.playing->name, true);
+  }
   nation_leader_list_iterate(nation_leaders(nation_by_number
                                             (selected_nation)), pleader) {
     str = QString::fromUtf8(nation_leader_name(pleader));
@@ -776,7 +778,13 @@ void popup_notify_goto_dialog(const char *headline, const char *lines,
 **************************************************************************/
 void popup_connect_msg(const char *headline, const char *message)
 {
-  qDebug() << Q_FUNC_INFO << "PORTME";
+  QMessageBox msg(gui()->central_wdg);
+
+  msg.setText(message);
+  msg.setStandardButtons(QMessageBox::Ok);
+  msg.setWindowTitle(headline);
+  msg.exec();
+
 }
 
 /**************************************************************************
