@@ -308,13 +308,12 @@ void fc_client::switch_page(int new_pg)
     gui()->infotab->chtwdg->update_widgets();
     status_bar->setVisible(false);
     gui()->infotab->chtwdg->update_font();
+    showMaximized();
+      /* For MS Windows, it might ingore first */
+    showMaximized();
     if (fullscreen_mode){
       gui()->showFullScreen();
       gui()->mapview_wdg->showFullScreen();
-    } else {
-      if (!isMaximized()) {
-        showMaximized();
-      }
     }
     menuBar()->setVisible(true);
     mapview_wdg->setFocus();
@@ -369,6 +368,22 @@ void fc_client::add_server_source(int sock)
 /****************************************************************************
   Event handler
 ****************************************************************************/
+bool fc_client::event(QEvent *event)
+{
+  if (event->type() == QEvent::User) {
+    version_message_event vmevt =
+        dynamic_cast<version_message_event&>(*event);
+    set_status_bar(vmevt.get_message());
+    return true;
+  } else {
+    return QMainWindow::event(event);
+  }
+}
+
+
+/****************************************************************************
+  Event filter
+****************************************************************************/
 bool fc_client::eventFilter(QObject *obj, QEvent *event)
 {
   if (obj == chat_line) {
@@ -421,7 +436,13 @@ void fc_client::remove_server_source()
 ****************************************************************************/
 void fc_client::server_input(int sock)
 {
+#if defined(Q_WS_WIN)
+  server_notifier->setEnabled(false);
+#endif
   input_from_server(sock);
+#if defined(Q_WS_WIN)
+  server_notifier->setEnabled(true);
+#endif
 }
 
 /****************************************************************************
@@ -432,6 +453,7 @@ void fc_client::chat()
   send_chat(chat_line->text().toUtf8().data());
   chat_history.prepend(chat_line->text());
   chat_line->clear();
+  history_pos = -1;
 }
 
 /****************************************************************************
