@@ -119,33 +119,26 @@ void fc_client::create_main_page(void)
 
   painter.setPen(Qt::white);
 
-  rev_ver = fc_svn_revision();
+  rev_ver = fc_git_revision();
+
   if (rev_ver == NULL) {
-    rev_ver = fc_git_revision();
-
-    if (rev_ver == NULL) {
-      /* TRANS: "version 2.6.0, Qt client" */
-      fc_snprintf(msgbuf, sizeof(msgbuf), _("%s%s, Qt client"),
-                  word_version(), VERSION_STRING);
-    } else {
-      fc_snprintf(msgbuf, sizeof(msgbuf), "%s%s",
-                  word_version(), VERSION_STRING);
-      painter.drawText(10,
-                       main_graphics.height() - fm.descent() - fm.height() * 2,
-                       msgbuf);
-
-      /* TRANS: "commit: [modified] <git commit id>" */
-      fc_snprintf(msgbuf, sizeof(msgbuf), _("commit: %s"), rev_ver);
-      painter.drawText(10,
-                       main_graphics.height() - fm.descent() - fm.height(),
-                       msgbuf);
-
-      strncpy(msgbuf, _("Qt client"), sizeof(msgbuf));
-    }
+    /* TRANS: "version 2.6.0, Qt client" */
+    fc_snprintf(msgbuf, sizeof(msgbuf), _("%s%s, Qt client"),
+                word_version(), VERSION_STRING);
   } else {
-    /* TRANS: "version 2.6.0 (r25000), Qt client" */
-    fc_snprintf(msgbuf, sizeof(msgbuf), _("%s%s (%s), Qt client"),
-                word_version(), VERSION_STRING, rev_ver);
+    fc_snprintf(msgbuf, sizeof(msgbuf), "%s%s",
+                word_version(), VERSION_STRING);
+    painter.drawText(10,
+                     main_graphics.height() - fm.descent() - fm.height() * 2,
+                     msgbuf);
+
+    /* TRANS: "commit: [modified] <git commit id>" */
+    fc_snprintf(msgbuf, sizeof(msgbuf), _("commit: %s"), rev_ver);
+    painter.drawText(10,
+                     main_graphics.height() - fm.descent() - fm.height(),
+                     msgbuf);
+
+    strncpy(msgbuf, _("Qt client"), sizeof(msgbuf));
   }
 
   painter.drawText(main_graphics.width()-fm.width(msgbuf)-10,
@@ -364,10 +357,12 @@ void fc_client::create_network_page(void)
   network_button = new QPushButton(_("Connect"));
   page_network_grid_layout->addWidget(network_button, 5, 5, 1, 1);
   connect(network_button, SIGNAL(clicked()), this, SLOT(slot_connect()));
+  connect(connect_login_edit, SIGNAL(returnPressed()),
+          this, SLOT(slot_connect()));
   connect(connect_password_edit, SIGNAL(returnPressed()),
-          network_button, SIGNAL(clicked()));
+          this, SLOT(slot_connect()));
   connect(connect_confirm_password_edit, SIGNAL(returnPressed()),
-          network_button, SIGNAL(clicked()));
+          this, SLOT(slot_connect()));
 
   connect_lan->setLayout(page_network_lan_layout);
   connect_metaserver->setLayout(page_network_wan_layout);
