@@ -254,6 +254,10 @@ void plr_model::notify_plr_changed(int row)
 void plr_model::populate()
 {
   plr_item *pi;
+
+  qDeleteAll(plr_list);
+  plr_list.clear();
+  beginResetModel();
   players_iterate(pplayer) {
     if ((is_barbarian(pplayer))){
       continue;
@@ -261,6 +265,7 @@ void plr_model::populate()
     pi = new plr_item(pplayer);
     plr_list << pi;
   } players_iterate_end;
+  endResetModel();
 }
 
 
@@ -477,6 +482,9 @@ void plr_widget::nation_selected(const QItemSelection &sl,
                    + ": "  + QString("</b>") + nl;
           added = true;
         }
+        if (gives_shared_vision(pplayer, other)) {
+          ally_str = ally_str + "(◐‿◑)";
+        }
         ally_str = ally_str + nation_plural_for_player(other) + ", ";
         entry_exist = true;
       }
@@ -702,7 +710,8 @@ void plr_widget::mousePressEvent(QMouseEvent *event)
 void plr_report::update_report(bool update_selection)
 {
   QModelIndex qmi;
-
+  int player_count = 0;
+  
   /* Force updating selected player information */
   if (update_selection == true) {
     qmi = plr_wdg->currentIndex();
@@ -712,6 +721,17 @@ void plr_report::update_report(bool update_selection)
     }
   }
 
+  players_iterate(pplayer) {
+    if ((is_barbarian(pplayer))){
+      continue;
+    }
+    player_count++;
+  } players_iterate_end;
+
+  if (player_count != plr_wdg->get_model()->rowCount()) {
+    plr_wdg->get_model()->populate();
+  }
+
   plr_wdg->header()->resizeSections(QHeaderView::ResizeToContents);
   meet_but->setDisabled(true);
   cancel_but->setDisabled(true);
