@@ -22,7 +22,7 @@
 #ifndef FC__MAPCTRL_H
 #define FC__MAPCTRL_H
 
-#include "SDL.h"
+#include "SDL/SDL.h"
 
 #include "fc_types.h"
 
@@ -39,7 +39,7 @@
 #define DEFAULT_UNITS_W		(78 + BLOCKU_W)
 #define DEFAULT_UNITS_H		52
 
-#else
+#else  /* SMALL_SCREEN */
 
 #define BLOCKM_W		52
 #define BLOCKU_W                28
@@ -48,7 +48,7 @@
 #define DEFAULT_UNITS_W		(158 + BLOCKU_W)
 #define DEFAULT_UNITS_H		104
 
-#endif
+#endif /* SMALL_SCREEN */
 
 extern int overview_w;
 extern int overview_h;
