@@ -27,7 +27,7 @@
 struct widget *pOptions_Button;
 
 void popup_optiondlg(void);
-void popdown_optiondlg(void);
+void popdown_optiondlg(bool leave_game);
 
 void init_options_button(void);
 void enable_options_button(void);
