@@ -22,7 +22,7 @@
 #ifndef FC__UNISTRING_H
 #define FC__UNISTRING_H
 
-#include "SDL.h"
+#include "SDL/SDL.h"
 
 size_t unistrlen(const Uint16 *pUniString);
 Uint16 *unistrcpy(Uint16 *pToUniString, const Uint16 *pFromUniString);
