@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -286,47 +286,46 @@ static void add_target_to_worklist(struct widget *pTarget)
   flush_dirty();
 }
 
-/*
- * Find if two targets are the same class (unit, imprv. , wonder).
- * This is needed by calculation of change production shields penalty.
- * [similar to are_universals_equal()]
- */
-static bool are_the_same_class(const struct universal one,
-			       const struct universal two)
+/**************************************************************************
+  Find if two targets are the same class (unit, imprv. , wonder).
+  This is needed by calculation of change production shields penalty.
+  [similar to are_universals_equal()]
+**************************************************************************/
+static bool are_prods_same_class(const struct universal one,
+                                 const struct universal two)
 {
   if (one.kind != two.kind) {
     return FALSE;
   }
-  if (VUT_UTYPE == one.kind) {
-    return one.value.utype == two.value.utype;
-  }
+
   if (VUT_IMPROVEMENT == one.kind) {
     if (is_wonder(one.value.building)) {
       return is_wonder(two.value.building);
+    } else {
+      return !is_wonder(two.value.building);
     }
-    return (one.value.building == two.value.building);
   }
+
   return FALSE;
 }
 
-/*
- * Change production in editor shell, callculate production shields penalty and
- * refresh production progress label
- */
+/**************************************************************************
+  Change production in editor shell, calculate production shields penalty and
+  refresh production progress label
+**************************************************************************/
 static void change_production(struct universal prod)
 {
-    
-  if(!are_the_same_class(pEditor->currently_building, prod)) {
-    if(pEditor->stock != pEditor->pCity->shield_stock) {
-      if(are_the_same_class(pEditor->pCity->production, prod)) {
-	pEditor->stock = pEditor->pCity->shield_stock;
+  if (!are_prods_same_class(pEditor->currently_building, prod)) {
+    if (pEditor->stock != pEditor->pCity->shield_stock) {
+      if (are_prods_same_class(pEditor->pCity->production, prod)) {
+        pEditor->stock = pEditor->pCity->shield_stock;
       }
     } else {
       pEditor->stock =
-	  city_change_production_penalty(pEditor->pCity, prod);
-    }	  	  
+        city_change_production_penalty(pEditor->pCity, prod);
+    }
   }
-      
+
   pEditor->currently_building = prod;
   refresh_production_label(pEditor->stock);
 
@@ -1185,22 +1184,21 @@ void popup_worklist_editor(struct city *pCity, struct global_worklist *pGWL)
   pBuf->action = popdown_worklist_editor_callback;
   set_wstate(pBuf, FC_WS_NORMAL);
   pBuf->key = SDLK_ESCAPE;
-    
+
   add_to_gui_list(ID_BUTTON, pBuf);
   /* --------------------------- */
   /* work list */
-  
+
   /*
-     pWidget->data filed will contains postion of target in worklist all
+     pWidget->data filed will contains position of target in worklist all
      action on worklist (swap/romove/add) must correct this fields
-     
+
      Production Widget Label in worklist Widget list
      will have this field NULL
   */
-  
+
   pEditor->pWork = fc_calloc(1, sizeof(struct ADVANCED_DLG));
 
-  
   pEditor->pWork->pScroll = fc_calloc(1, sizeof(struct ScrollBar));
   pEditor->pWork->pScroll->count = 0;
   pEditor->pWork->pScroll->active = MAX_LEN_WORKLIST;
