@@ -18,6 +18,9 @@
 /* utility */
 #include "log.h"
 
+/* gui main header */
+#include "gui_stub.h"
+
 #include "optiondlg.h"
 
 
