@@ -12,10 +12,9 @@
 ***********************************************************************/
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include <fc_config.h>
 #endif
 
-#include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -31,9 +30,9 @@
 #include <X11/Xaw/Toggle.h>
 #include <X11/Xaw/Viewport.h>
 
+/* common & utility */
 #include "city.h"
 #include "fcintl.h"
-#include "game.h"
 #include "log.h"
 #include "mem.h"
 #include "packets.h"
@@ -41,8 +40,9 @@
 #include "support.h"
 #include "unit.h"
 
+/* client */
+#include "client_main.h"
 #include "climisc.h"
-#include "clinet.h"
 
 #include "chatline.h"
 #include "citydlg.h"
@@ -165,7 +165,7 @@ static char *get_city_table_header(void)
 /****************************************************************
 ...
 ****************************************************************/
-void popup_city_report_dialog(bool make_modal)
+void city_report_dialog_popup(bool make_modal)
 {
   if(!city_dialog_shell) {
       Position x, y;
@@ -195,7 +195,7 @@ void popup_city_report_dialog(bool make_modal)
 /****************************************************************
   Closes the cityrep dialog.
 ****************************************************************/
-void popdown_city_report_dialog(void)
+void city_report_dialog_popdown(void)
 {
   if (city_dialog_shell) {
     if (city_dialog_shell_is_modal) {
@@ -307,7 +307,7 @@ void create_city_report_dialog(bool make_modal)
 	 XtParseTranslationTable("<Message>WM_PROTOCOLS: msg-close-city-report()"));
   }
 
-  city_report_dialog_update();
+  real_city_report_dialog_update();
 }
 
 /****************************************************************
@@ -321,7 +321,7 @@ void city_list_callback(Widget w, XtPointer client_data,
 
   if(ret->list_index!=XAW_LIST_NONE && 
      (pcity=cities_in_list[ret->list_index])) {
-    struct city_production targets[MAX_NUM_PRODUCTION_TARGETS];
+    struct universal targets[MAX_NUM_PRODUCTION_TARGETS];
     struct item items[MAX_NUM_PRODUCTION_TARGETS];
     int targets_used = 0;
     size_t i;
@@ -338,18 +338,18 @@ void city_list_callback(Widget w, XtPointer client_data,
 				        city_change_command,
 				        NULL);
 
-    impr_type_iterate(impr) {
-      if (can_build_improvement(pcity, impr)) {
-	targets[targets_used].is_unit = false;
-	targets[targets_used].value = impr;
+    improvement_iterate(pimprove) {
+      if (can_city_build_improvement_now(pcity, pimprove)) {
+	targets[targets_used].kind = VUT_IMPROVEMENT;
+	targets[targets_used].value.building = pimprove;
 	targets_used++;
       }
-    } impr_type_iterate_end;
+    } improvement_iterate_end;
 
     unit_type_iterate(punittype) {
-      if (can_build_unit(pcity, punittype)) {
-	targets[targets_used].is_unit = true;
-	targets[targets_used].value = punittype->index;
+      if (can_city_build_unit_now(pcity, punittype)) {
+	targets[targets_used].kind = VUT_UTYPE;
+	targets[targets_used].value.utype = punittype;
 	targets_used++;
       }
     } unit_type_iterate_end;
@@ -382,7 +382,7 @@ void city_change_callback(Widget w, XtPointer client_data,
 {
   XawListReturnStruct *ret=XawListShowCurrent(city_list);
   struct city *pcity;
-  struct city_production production;
+  struct universal production;
 
   if(ret->list_index!=XAW_LIST_NONE && 
      (pcity=cities_in_list[ret->list_index])) {
@@ -431,20 +431,20 @@ void city_refresh_callback(Widget w, XtPointer client_data,
     struct city *pcity = cities_in_list[ret->list_index];
 
     if (pcity) {
-      dsend_packet_city_refresh(&aconnection, pcity->id);
+      dsend_packet_city_refresh(&client.conn, pcity->id);
     }
   } else {
-    dsend_packet_city_refresh(&aconnection, 0);
+    dsend_packet_city_refresh(&client.conn, 0);
   }
 }
 
 /****************************************************************
 ...
 *****************************************************************/
-void city_close_callback(Widget w, XtPointer client_data, 
-			 XtPointer call_data)
+void city_close_callback(Widget w, XtPointer client_data,
+                         XtPointer call_data)
 {
-  popdown_city_report_dialog();
+  city_report_dialog_popdown();
 }
 
 /****************************************************************
@@ -502,11 +502,12 @@ void city_config_callback(Widget w, XtPointer client_data,
 /****************************************************************
 ...
 *****************************************************************/
-void city_report_dialog_update(void)
+void real_city_report_dialog_update(void)
 {
-  if (is_report_dialogs_frozen() || !game.player_ptr) {
+  if (!client_has_player()) {
     return;
   }
+
   if(city_dialog_shell) {
     int i=0, n;
     Dimension width;
@@ -514,14 +515,14 @@ void city_report_dialog_update(void)
     static char **city_list_text = NULL;
     const char *report_title;
 
-    n = city_list_size(game.player_ptr->cities);
-    freelog(LOG_DEBUG, "%d cities in report", n);
+    n = city_list_size(client.conn.playing->cities);
+    log_debug("%d cities in report", n);
     if(n_alloc == 0 || n > n_alloc) {
       int j, n_prev = n_alloc;
       
       n_alloc *= 2;
       if (!n_alloc || n_alloc < n) n_alloc = n + 1;
-      freelog(LOG_DEBUG, "city report n_alloc increased to %d", n_alloc);
+      log_debug("city report n_alloc increased to %d", n_alloc);
       cities_in_list = fc_realloc(cities_in_list,
 				  n_alloc*sizeof(*cities_in_list));
       city_list_text = fc_realloc(city_list_text, n_alloc*sizeof(char*));
@@ -546,17 +547,17 @@ void city_report_dialog_update(void)
      * having to find city corresponding to id for each comparison.
      */
     i=0;
-    city_list_iterate(game.player_ptr->cities, pcity) {
+    city_list_iterate(client.conn.playing->cities, pcity) {
       cities_in_list[i++] = pcity;
     } city_list_iterate_end;
-    assert(i==n);
+    fc_assert(i==n);
     qsort(cities_in_list, n, sizeof(struct city*), city_name_compare);
     for(i=0; i<n; i++) {
       get_city_text(cities_in_list[i], city_list_text[i], MAX_LEN_CITY_TEXT);
     }
     i = n;
     if(!n) {
-      mystrlcpy(city_list_text[0], 
+      fc_strlcpy(city_list_text[0], 
 		"                                                             ",
 		MAX_LEN_CITY_TEXT);
       i=1;
@@ -585,12 +586,13 @@ void city_report_dialog_update(void)
 /****************************************************************
   Update the text for a single city in the city report
 *****************************************************************/
-void city_report_dialog_update_city(struct city *pcity)
+void real_city_report_update_city(struct city *pcity)
 {
   int i;
 
-  if(is_report_dialogs_frozen()) return;
-  if(!city_dialog_shell) return;
+  if (!city_dialog_shell) {
+    return;
+  }
 
   for(i=0; cities_in_list[i]; i++)  {
     if(cities_in_list[i]==pcity)  {
@@ -605,7 +607,7 @@ void city_report_dialog_update_city(struct city *pcity)
       }
       get_city_text(pcity, new_city_line, sizeof(new_city_line));
       if(strcmp(new_city_line, list[i])==0) return; /* no change */
-      mystrlcpy(list[i], new_city_line, MAX_LEN_CITY_TEXT);
+      fc_strlcpy(list[i], new_city_line, MAX_LEN_CITY_TEXT);
 
       /* It seems really inefficient to regenerate the whole list just to
          change one line.  It's also annoying to have to set the size
@@ -621,7 +623,7 @@ void city_report_dialog_update_city(struct city *pcity)
       return;
     }
   }
-  city_report_dialog_update();
+  real_city_report_dialog_update();
 }
 
 /****************************************************************
@@ -697,7 +699,7 @@ void create_city_report_config_dialog(void)
   config_toggle = fc_realloc(config_toggle,
 			     NUM_CREPORT_COLS * sizeof(*config_toggle));
   for(i=0, spec=city_report_specs+i; i<NUM_CREPORT_COLS; i++, spec++) {
-    my_snprintf(buf, sizeof(buf), "%-32s", spec->explanation);
+    fc_snprintf(buf, sizeof(buf), "%-32s", spec->explanation);
     above = (i==1)?config_label:config_optlabel;
 
     config_optlabel = XtVaCreateManagedWidget("cityconfiglabel", 
@@ -751,7 +753,7 @@ void config_ok_command_callback(Widget w, XtPointer client_data,
     spec->show = (bool) b;
   }
   config_shell=0;
-  city_report_dialog_update();
+  real_city_report_dialog_update();
 }
 
 /**************************************************************************
@@ -816,8 +818,6 @@ static void popup_chgall_dialog (Widget parent)
   struct chgall_data *state;
   Widget shell;
   Widget main_form;
-  Widget fr_label;
-  Widget to_label;
   Widget fr_viewport;
   Widget to_viewport;
   Position x, y;
@@ -867,24 +867,6 @@ static void popup_chgall_dialog (Widget parent)
      NULL
     );
 
-  fr_label =
-    I_LW(XtVaCreateManagedWidget
-    (
-     "chgallfrlabel",
-     labelWidgetClass, 
-     main_form,
-     NULL
-    ));
-
-  to_label =
-    I_LW(XtVaCreateManagedWidget
-    (
-     "chgalltolabel",
-     labelWidgetClass, 
-     main_form,
-     NULL
-    ));
-
   fr_viewport =
     XtVaCreateManagedWidget
     (
@@ -1078,14 +1060,14 @@ static void chgall_refresh_command_callback(Widget w,
 					    XtPointer call_data)
 {
   struct chgall_data *state = (struct chgall_data *) client_data;
-  struct city_production targets[MAX_NUM_PRODUCTION_TARGETS];
+  struct universal targets[MAX_NUM_PRODUCTION_TARGETS];
   struct item items[MAX_NUM_PRODUCTION_TARGETS];
   int i;
 
   state->fr_count = collect_currently_building_targets(targets);
   name_and_sort_items(targets, state->fr_count, items, false, NULL);
   for (i = 0; i < state->fr_count; i++) {
-    state->fr_list[i] = mystrdup(items[i].descr);
+    state->fr_list[i] = fc_strdup(items[i].descr);
     state->fr_cids[i] = cid_encode(items[i].item);
   }
   XawListChange(state->w.fr, state->fr_list, state->fr_count, 0, FALSE);
@@ -1093,7 +1075,7 @@ static void chgall_refresh_command_callback(Widget w,
   state->to_count = collect_buildable_targets(targets);
   name_and_sort_items(targets, state->to_count, items, TRUE, NULL);
   for (i = 0; i < state->to_count; i++) {
-    state->to_list[i] = mystrdup(items[i].descr);
+    state->to_list[i] = fc_strdup(items[i].descr);
     state->to_cids[i] = cid_encode(items[i].item);
   }
   XawListChange(state->w.to, state->to_list, state->to_count, 0, FALSE);
