@@ -56,7 +56,7 @@ enum MenuID {
   MENU_VIEW_SHOW_CITY_PRODUCTIONS,
   MENU_VIEW_SHOW_TERRAIN,
   MENU_VIEW_SHOW_COASTLINE,
-  MENU_VIEW_SHOW_ROADS_RAILS,
+  MENU_VIEW_SHOW_PATHS,
   MENU_VIEW_SHOW_IRRIGATION,
   MENU_VIEW_SHOW_MINES,
   MENU_VIEW_SHOW_BASES,
