@@ -12,7 +12,7 @@
 ***********************************************************************/
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include <fc_config.h>
 #endif
 
 #include <stdio.h>
@@ -20,32 +20,37 @@
 #include <string.h>
 
 #include <X11/Intrinsic.h>
+#include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
+#include <X11/Xaw/AsciiText.h>  
+#include <X11/Xaw/Command.h>
 #include <X11/Xaw/Form.h>
 #include <X11/Xaw/Label.h>
-#include <X11/Xaw/Command.h>
+#include <X11/Xaw/List.h>
 #include <X11/Xaw/MenuButton.h>
 #include <X11/Xaw/SimpleMenu.h>
 #include <X11/Xaw/SmeBSB.h>
-#include <X11/Xaw/List.h>
-#include <X11/Xaw/Viewport.h>
-#include <X11/Xaw/AsciiText.h>  
 #include <X11/Xaw/Toggle.h>     
-#include <X11/IntrinsicP.h>
+#include <X11/Xaw/Viewport.h>
 
-
-#include "city.h"
+/* utility */
 #include "fcintl.h"
-#include "game.h"
+#include "log.h"
+#include "mem.h"
+
+/* common */
+#include "city.h"
+#include "packets.h"
+#include "worklist.h"
+
+/* client */
+#include "client_main.h"
+#include "climisc.h"
+
 #include "gui_main.h"
 #include "gui_stuff.h"
 #include "helpdlg.h"
 #include "inputdlg.h"
-#include "mem.h"
-#include "packets.h"
-#include "worklist.h"
-#include "climisc.h"
-#include "clinet.h"
 
 #include "wldlg.h"
 
@@ -62,7 +67,7 @@ struct worklist_report_dialog {
   struct player *pplr;
   char worklist_names[MAX_NUM_WORKLISTS][MAX_LEN_NAME];
   char *worklist_names_ptrs[MAX_NUM_WORKLISTS+1];
-  struct worklist *worklist_ptr[MAX_NUM_WORKLISTS];
+  struct global_worklist *worklist_ptr[MAX_NUM_WORKLISTS];
   int wl_idx;
 };
 
@@ -79,7 +84,7 @@ struct worklist_dialog {
   Widget shell;
 
   struct city *pcity;
-  struct worklist *pwl;
+  int global_worklist_id;
 
   void *parent_data;
   WorklistOkCallback ok_callback;
@@ -101,9 +106,10 @@ static Widget worklist_report_shell = NULL;
 static struct worklist_report_dialog *report_dialog;
 
 
-static int uni_id(struct worklist *pwl, int wlinx);
+static int uni_id(const struct worklist *pwl, int wlinx);
 
-static void worklist_id_to_name(char buf[], int id, bool is_unit, 
+static void worklist_id_to_name(char buf[],
+				struct universal production,
 				struct city *pcity);
 
 static void rename_worklist_callback(Widget w, XtPointer client_data, 
@@ -153,7 +159,7 @@ static void worklist_avail_help_callback(Widget w, XtPointer client_data,
 					  XtPointer call_data);
 static void worklist_show_advanced_callback(Widget w, XtPointer client_data, 
 					  XtPointer call_data);
-static void worklist_help(int id, bool is_unit);
+static void worklist_help(struct universal production);
 static void worklist_populate_worklist(struct worklist_dialog *pdialog);
 static void worklist_populate_targets(struct worklist_dialog *pdialog);
 
@@ -302,7 +308,7 @@ void popup_worklists_dialog(struct player *pplr)
   that can be made.  Otherwise, just list everything that technology
   will allow.
 *************************************************************************/
-Widget popup_worklist(struct worklist *pwl, struct city *pcity,
+Widget popup_worklist(struct city *pcity, struct global_worklist *pgwl,
 		      Widget parent, void *parent_data,
 		      WorklistOkCallback ok_cb,
 		      WorklistCancelCallback cancel_cb)
@@ -333,7 +339,7 @@ Widget popup_worklist(struct worklist *pwl, struct city *pcity,
   pdialog = fc_malloc(sizeof(struct worklist_dialog));
 
   pdialog->pcity = pcity;
-  pdialog->pwl = pwl;
+  pdialog->global_worklist_id = pgwl ? global_worklist_id(pgwl) : -1;
   pdialog->shell = parent;
   pdialog->parent_data = parent_data;
   pdialog->ok_callback = ok_cb;
@@ -561,36 +567,38 @@ void update_worklist_report_dialog(void)
 }
 
 /****************************************************************
-
+  Returns an unique id for element in units + buildings sequence
 *****************************************************************/
-int uni_id(struct worklist *pwl, int inx)
+int uni_id(const struct worklist *pwl, int inx)
 {
-  if ((inx < 0) || (inx >= MAX_LEN_WORKLIST)) {
+  if ((inx < 0) || (inx >= worklist_length(pwl))) {
     return WORKLIST_END;
-  } else if (pwl->wlefs[inx] == WEF_UNIT) {
-    return pwl->wlids[inx] + B_LAST;
-  } else if (pwl->wlefs[inx] == WEF_IMPR) {
-    return pwl->wlids[inx];
+  } else if (VUT_UTYPE == pwl->entries[inx].kind) {
+    return utype_number(pwl->entries[inx].value.utype) + B_LAST;
   } else {
-    return WORKLIST_END;
+    return improvement_number(pwl->entries[inx].value.building);
   }
 }
 
 /****************************************************************
 
 *****************************************************************/
-void worklist_id_to_name(char buf[], int id, bool is_unit, 
+void worklist_id_to_name(char buf[],
+			 struct universal production,
 			 struct city *pcity)
 {
-  if (is_unit)
+  if (VUT_UTYPE == production.kind)
     sprintf(buf, "%s (%d)",
-	    get_unit_name(id), unit_build_shield_cost(id));
+	    utype_values_translation(production.value.utype),
+	    utype_build_shield_cost(production.value.utype));
   else if (pcity)
     sprintf(buf, "%s (%d)",
-	    get_impr_name_ex(pcity, id), impr_build_shield_cost(id));
+	    city_improvement_name_translation(pcity, production.value.building),
+	    impr_build_shield_cost(production.value.building));
   else
     sprintf(buf, "%s (%d)",
-	    get_improvement_name(id), impr_build_shield_cost(id));
+	    improvement_name_translation(production.value.building),
+	    impr_build_shield_cost(production.value.building));
 }
 
 
@@ -607,19 +615,20 @@ void rename_worklist_callback(Widget w, XtPointer client_data,
   pdialog = (struct worklist_report_dialog *)client_data;
   retList = XawListShowCurrent(pdialog->list);
 
-  if (retList->list_index == XAW_LIST_NONE)
+  if (retList->list_index == XAW_LIST_NONE) {
     return;
+  }
 
   pdialog->wl_idx = retList->list_index;
 
   input_dialog_create(worklist_report_shell,
-		      "renameworklist",
-		      _("What should the new name be?"),
-		      pdialog->pplr->worklists[pdialog->wl_idx].name,
-		      rename_worklist_sub_callback,
-		      (XtPointer)pdialog,
-		      rename_worklist_sub_callback,
-		      (XtPointer)NULL);
+                      "renameworklist",
+                      _("What should the new name be?"),
+                      global_worklist_name(pdialog->worklist_ptr[pdialog->wl_idx]),
+                      rename_worklist_sub_callback,
+                      (XtPointer)pdialog,
+                      rename_worklist_sub_callback,
+                      (XtPointer)NULL);
 }
 
 /****************************************************************
@@ -633,13 +642,11 @@ void rename_worklist_sub_callback(Widget w, XtPointer client_data,
   pdialog = (struct worklist_report_dialog *)client_data;
 
   if (pdialog) {
-    strncpy(pdialog->pplr->worklists[pdialog->wl_idx].name,
-            input_dialog_get_input(w), MAX_LEN_NAME);
-    pdialog->pplr->worklists[pdialog->wl_idx].name[MAX_LEN_NAME - 1] = '\0';
-
-    update_worklist_report_dialog();
+      global_worklist_set_name(pdialog->worklist_ptr[pdialog->wl_idx],
+                               input_dialog_get_input(w));
+      update_worklist_report_dialog();
   }
-  
+
   input_dialog_destroy(w);
 }
 
@@ -649,26 +656,7 @@ void rename_worklist_sub_callback(Widget w, XtPointer client_data,
 void insert_worklist_callback(Widget w, XtPointer client_data, 
 			      XtPointer call_data)
 {
-  struct worklist_report_dialog *pdialog;
-  int j;
-
-  pdialog = (struct worklist_report_dialog *)client_data;
-
-  /* Find the next free worklist for this player */
-
-  for (j = 0; j < MAX_NUM_WORKLISTS; j++)
-    if (!pdialog->pplr->worklists[j].is_valid)
-      break;
-
-  /* No more worklist slots free.  (!!!Maybe we should tell the user?) */
-  if (j == MAX_NUM_WORKLISTS)
-    return;
-
-  /* Validate this slot. */
-  init_worklist(&pdialog->pplr->worklists[j]);
-  pdialog->pplr->worklists[j].is_valid = TRUE;
-  strcpy(pdialog->pplr->worklists[j].name, _("empty worklist"));
-
+  (void) global_worklist_new(_("empty worklist"));
   update_worklist_report_dialog();
 }
 
@@ -681,29 +669,15 @@ void delete_worklist_callback(Widget w, XtPointer client_data,
 {
   struct worklist_report_dialog *pdialog;
   XawListReturnStruct *retList;
-  int i, j;
 
   pdialog = (struct worklist_report_dialog *)client_data;
   retList = XawListShowCurrent(pdialog->list);
 
-  if (retList->list_index == XAW_LIST_NONE)
+  if (retList->list_index == XAW_LIST_NONE) {
     return;
-
-  /* Look for the last free worklist */
-  for (i = 0; i < MAX_NUM_WORKLISTS; i++)
-    if (!pdialog->pplr->worklists[i].is_valid)
-      break;
-
-  for (j = retList->list_index; j < i-1; j++) {
-    copy_worklist(&pdialog->pplr->worklists[j], 
-                  &pdialog->pplr->worklists[j+1]);
   }
 
-  /* The last worklist in the set is no longer valid -- it's been slid up
-   * one slot. */
-  pdialog->pplr->worklists[i-1].is_valid = FALSE;
-  strcpy(pdialog->pplr->worklists[i-1].name, "\0");
-  
+  global_worklist_destroy(pdialog->worklist_ptr[pdialog->wl_idx]);
   update_worklist_report_dialog();
 }
 
@@ -719,14 +693,15 @@ void edit_worklist_callback(Widget w, XtPointer client_data,
   pdialog = (struct worklist_report_dialog *)client_data;
   retList = XawListShowCurrent(pdialog->list);
 
-  if (retList->list_index == XAW_LIST_NONE)
+  if (retList->list_index == XAW_LIST_NONE) {
     return;
+  }
 
   pdialog->wl_idx = retList->list_index;
 
-  popup_worklist(pdialog->worklist_ptr[pdialog->wl_idx], NULL, 
-		 worklist_report_shell,
-		 pdialog, commit_player_worklist, NULL);
+  popup_worklist(NULL, pdialog->worklist_ptr[pdialog->wl_idx],
+                 worklist_report_shell,
+                 pdialog, commit_player_worklist, NULL);
 }
 
 /****************************************************************
@@ -738,7 +713,7 @@ void commit_player_worklist(struct worklist *pwl, void *data)
 
   pdialog = (struct worklist_report_dialog *)data;
 
-  copy_worklist(&pdialog->pplr->worklists[pdialog->wl_idx], pwl);
+  global_worklist_set(pdialog->worklist_ptr[pdialog->wl_idx], pwl);
 }
 
 /****************************************************************
@@ -758,17 +733,18 @@ void close_worklistreport_callback(Widget w, XtPointer client_data,
 *****************************************************************/
 void populate_worklist_report_list(struct worklist_report_dialog *pdialog)
 {
-  int i, n;
+  int n = 0;
 
-  for (i = 0, n = 0; i < MAX_NUM_WORKLISTS; i++) {
-    if (pdialog->pplr->worklists[i].is_valid) {
-      strcpy(pdialog->worklist_names[n], pdialog->pplr->worklists[i].name);
-      pdialog->worklist_names_ptrs[n] = pdialog->worklist_names[n];
-      pdialog->worklist_ptr[n] = &pdialog->pplr->worklists[i];
-      n++;
+  global_worklists_iterate(pgwl) {
+    if (n >= MAX_NUM_WORKLISTS) {
+      break;
     }
-  }
-  
+    strcpy(pdialog->worklist_names[n], global_worklist_name(pgwl));
+    pdialog->worklist_names_ptrs[n] = pdialog->worklist_names[n];
+    pdialog->worklist_ptr[n] = pgwl;
+    n++;
+  } global_worklists_iterate_end;
+
   /* Terminators */
   pdialog->worklist_names_ptrs[n] = NULL;
 }
@@ -828,20 +804,18 @@ void insert_into_worklist(struct worklist_dialog *pdialog,
 			  int before, cid cid)
 {
   int i, first_free;
-  int target = cid_id(cid);
-  bool is_unit = cid_is_unit(cid);
+  struct universal target = cid_decode(cid);
 
   /* If this worklist is a city worklist, double check that the city
      really can (eventually) build the target.  We've made sure that
      the list of available targets is okay for this city, but a global
      worklist may try to insert an odd-ball unit or target. */
-  if (pdialog->pcity &&
-      ((is_unit  && !can_eventually_build_unit(pdialog->pcity, target)) ||
-       (!is_unit && !can_eventually_build_improvement(pdialog->pcity, target))))
+  if (pdialog->pcity
+      && !can_city_build_later(pdialog->pcity, target)) {
     /* Nope, this city can't build this target, ever.  Don't put it into
        the worklist. */
     return;
-    
+  }
 
   /* Find the first free element in the worklist */
   for (first_free = 0; first_free < MAX_LEN_WORKLIST; first_free++)
@@ -876,7 +850,7 @@ void insert_into_worklist(struct worklist_dialog *pdialog,
   pdialog->worklist_ids[before] = cid;
   
   worklist_id_to_name(pdialog->worklist_names[before],
-		      target, is_unit, pdialog->pcity);
+		      target, pdialog->pcity);
   pdialog->worklist_names_ptrs[before] = pdialog->worklist_names[before];
 }
 
@@ -927,6 +901,7 @@ void worklist_insert_common_callback(struct worklist_dialog *pdialog,
 {
   int target;
   int i, len;
+  struct universal production;
 
   /* Is there anything selected to insert? */
   if (retAvail->list_index == XAW_LIST_NONE)
@@ -937,9 +912,10 @@ void worklist_insert_common_callback(struct worklist_dialog *pdialog,
 
   if (retAvail->list_index >= pdialog->worklist_avail_num_targets) {
     /* target is a global worklist id */
-    struct player *pplr = city_owner(pdialog->pcity);
+    /* struct player *pplr = city_owner(pdialog->pcity); */
     int wl_idx = pdialog->worklist_avail_ids[retAvail->list_index];
-    struct worklist *pwl = &pplr->worklists[wl_idx];
+    const struct global_worklist *pgwl = global_worklist_by_id(wl_idx);
+    const struct worklist *pwl = global_worklist_get(pgwl);
 
     for (i = 0; i < MAX_LEN_WORKLIST && uni_id(pwl, i) != WORKLIST_END; i++) {
       insert_into_worklist(pdialog, where, uni_id(pwl, i));
@@ -948,12 +924,16 @@ void worklist_insert_common_callback(struct worklist_dialog *pdialog,
     }
   } else if (retAvail->list_index >= 
 	     pdialog->worklist_avail_num_improvements) {
-    /* target is an improvement or wonder */
-    insert_into_worklist(pdialog, where, cid_encode(TRUE, target));
+    /* target is a unit */
+    production.kind = VUT_UTYPE;
+    production.value.utype = utype_by_number(target);
+    insert_into_worklist(pdialog, where, cid_encode(production));
     where++;
   } else {
-    /* target is a unit */
-    insert_into_worklist(pdialog, where, cid_encode(FALSE, target));
+    /* target is an improvement or wonder */
+    production.kind = VUT_IMPROVEMENT;
+    production.value.building = improvement_by_number(target);
+    insert_into_worklist(pdialog, where, cid_encode(production));
     where++;
   }
 
@@ -1086,35 +1066,35 @@ void worklist_ok_callback(Widget w, XtPointer client_data, XtPointer call_data)
 {
   struct worklist_dialog *pdialog;
   struct worklist wl;
+  struct universal production;
   int i;
   
   pdialog=(struct worklist_dialog *)client_data;
   
   /* Fill in this worklist with the parameters set in the worklist 
      dialog. */
-  init_worklist(&wl);
+  worklist_init(&wl);
   
   for (i = 0; i < MAX_LEN_WORKLIST; i++) {
     if (pdialog->worklist_ids[i] == WORKLIST_END) {
-      wl.wlefs[i] = WEF_END;
-      wl.wlids[i] = 0;
+      continue;
     } else if (pdialog->worklist_ids[i] >= B_LAST) {
-      wl.wlefs[i] = WEF_UNIT;
-      wl.wlids[i] = pdialog->worklist_ids[i] - B_LAST;
+      production.kind = VUT_UTYPE;
+      production.value.utype = utype_by_number(pdialog->worklist_ids[i] - B_LAST);
+      worklist_append(&wl, production);
     } else if (pdialog->worklist_ids[i] >= 0) {
-      wl.wlefs[i] = WEF_IMPR;
-      wl.wlids[i] = pdialog->worklist_ids[i];
+      production.kind = VUT_IMPROVEMENT;
+      production.value.building = improvement_by_number(pdialog->worklist_ids[i]);
+      worklist_append(&wl, production);
     } else {
-      wl.wlefs[i] = WEF_END;
-      wl.wlids[i] = 0;
+      continue;
     }
   }
-  strcpy(wl.name, pdialog->pwl->name);
-  wl.is_valid = pdialog->pwl->is_valid;
-  
+
   /* Invoke the dialog's parent-specified callback */
-  if (pdialog->ok_callback)
+  if (pdialog->ok_callback) {
     (*pdialog->ok_callback)(&wl, pdialog->parent_data);
+  }
 
   /* Cleanup. */
   XtDestroyWidget(XtParent(XtParent(w)));
@@ -1151,21 +1131,20 @@ void worklist_worklist_help_callback(Widget w, XtPointer client_data,
 {
   struct worklist_dialog *pdialog;
   XawListReturnStruct *ret;
-  int id;
-  bool is_unit = FALSE;
+  struct universal production;
 
   pdialog=(struct worklist_dialog *)client_data;
 
   ret = XawListShowCurrent(pdialog->worklist);
   if(ret->list_index!=XAW_LIST_NONE) {
     cid cid = pdialog->worklist_ids[ret->list_index];
-    is_unit = cid_is_unit(cid);
-    id = cid_id(cid);
+    production = cid_decode(cid);
   } else {
-    id = -1;
+    production.kind = VUT_NONE;
+    production.value.building = NULL;
   }
 
-  worklist_help(id, is_unit);
+  worklist_help(production);
 }
 
 void worklist_avail_help_callback(Widget w, XtPointer client_data, 
@@ -1173,8 +1152,7 @@ void worklist_avail_help_callback(Widget w, XtPointer client_data,
 {
   struct worklist_dialog *pdialog;
   XawListReturnStruct *ret;
-  int id;
-  bool is_unit = FALSE;
+  struct universal production;
 
   pdialog=(struct worklist_dialog *)client_data;
 
@@ -1182,28 +1160,35 @@ void worklist_avail_help_callback(Widget w, XtPointer client_data,
   if(ret->list_index!=XAW_LIST_NONE) {
     if (ret->list_index >= pdialog->worklist_avail_num_targets) {
       /* target is a global worklist id */
-      id = -1;
+      production.kind = VUT_NONE;
+      production.value.building = NULL;
     } else {
-      id = pdialog->worklist_avail_ids[ret->list_index];
-      is_unit = ret->list_index >= pdialog->worklist_avail_num_improvements;
+      production =
+        universal_by_number((ret->list_index >= pdialog->worklist_avail_num_improvements)
+                               ? VUT_UTYPE : VUT_IMPROVEMENT,
+                               pdialog->worklist_avail_ids[ret->list_index]);
     }
   } else {
-    id = -1;
+    production.kind = VUT_NONE;
+    production.value.building = NULL;
   }
 
-  worklist_help(id, is_unit);
+  worklist_help(production);
 }
 
 
-void worklist_help(int id, bool is_unit)
+void worklist_help(struct universal production)
 {
-  if(id >= 0) {
-    if (is_unit) {
-      popup_help_dialog_typed(get_unit_type(id)->name, HELP_UNIT);
-    } else if(is_wonder(id)) {
-      popup_help_dialog_typed(get_improvement_name(id), HELP_WONDER);
+  if (production.value.building) {
+    if (VUT_UTYPE == production.kind) {
+      popup_help_dialog_typed(utype_name_translation(production.value.utype),
+					    HELP_UNIT);
+    } else if (is_great_wonder(production.value.building)) {
+      popup_help_dialog_typed(improvement_name_translation(production.value.building),
+						   HELP_WONDER);
     } else {
-      popup_help_dialog_typed(get_improvement_name(id), HELP_IMPROVEMENT);
+      popup_help_dialog_typed(improvement_name_translation(production.value.building),
+						   HELP_IMPROVEMENT);
     }
   }
   else
@@ -1240,32 +1225,40 @@ void worklist_populate_worklist(struct worklist_dialog *pdialog)
 {
   int i, n;
   int id;
-  int target;
-  bool is_unit;
+  struct universal target;
+  const struct worklist *pwl;
 
   n = 0;
   if (pdialog->pcity) {
     /* First element is the current build target of the city. */
-    id = pdialog->pcity->currently_building;
+    id = universal_number(&pdialog->pcity->production);
 
     worklist_id_to_name(pdialog->worklist_names[n],
-			id, pdialog->pcity->is_building_unit, pdialog->pcity);
+			pdialog->pcity->production, pdialog->pcity);
 
-    if (pdialog->pcity->is_building_unit)
+    if (VUT_UTYPE == pdialog->pcity->production.kind)
       id += B_LAST;
     pdialog->worklist_names_ptrs[n] = pdialog->worklist_names[n];
     pdialog->worklist_ids[n] = id;
     n++;
+    pwl = &pdialog->pcity->worklist;
+  } else {
+    const struct global_worklist *pgwl =
+      global_worklist_by_id(pdialog->global_worklist_id);
+
+    fc_assert(NULL != pgwl);
+
+    pwl = global_worklist_get(pgwl);
   }
 
   /* Fill in the rest of the worklist list */
   for (i = 0; n < MAX_LEN_WORKLIST &&
-	 uni_id(pdialog->pwl, i) != WORKLIST_END; i++, n++) {
-    worklist_peek_ith(pdialog->pwl, &target, &is_unit, i);
-    id = uni_id(pdialog->pwl, i);
+	 uni_id(pwl, i) != WORKLIST_END; i++, n++) {
+    worklist_peek_ith(pwl, &target, i);
+    id = uni_id(pwl, i);
 
     worklist_id_to_name(pdialog->worklist_names[n],
-			target, is_unit, pdialog->pcity);
+			target, pdialog->pcity);
 
     pdialog->worklist_names_ptrs[n] = pdialog->worklist_names[n];
     pdialog->worklist_ids[n] = id;
@@ -1282,12 +1275,15 @@ void worklist_populate_worklist(struct worklist_dialog *pdialog)
 *****************************************************************/
 void worklist_populate_targets(struct worklist_dialog *pdialog)
 {
-  int i, n;
-  struct player *pplr = game.player_ptr;
+  int n;
   Boolean b;
   int advanced_tech;
   int can_build, can_eventually_build;
-  
+  struct universal production;
+
+  if (!can_client_issue_orders()) {
+    return;
+  }
 
   n = 0;
 
@@ -1300,47 +1296,51 @@ void worklist_populate_targets(struct worklist_dialog *pdialog)
     advanced_tech = False;
  
   /*     + First, improvements and Wonders. */
-  impr_type_iterate(i) {
+  improvement_iterate(pimprove) {
     /* Can the player (eventually) build this improvement? */
-    can_build = can_player_build_improvement(pplr,i);
-    can_eventually_build = can_player_eventually_build_improvement(pplr,i);
+    can_build = can_player_build_improvement_now(client.conn.playing, pimprove);
+    can_eventually_build = can_player_build_improvement_later(client.conn.playing, pimprove);
 
     /* If there's a city, can the city build the improvement? */
     if (pdialog->pcity) {
-      can_build = can_build && can_build_improvement(pdialog->pcity, i);
+      can_build = can_build && can_city_build_improvement_now(pdialog->pcity, pimprove);
       can_eventually_build = can_eventually_build &&
-	can_eventually_build_improvement(pdialog->pcity, i);
+	can_city_build_improvement_later(pdialog->pcity, pimprove);
     }
     
     if (( advanced_tech && can_eventually_build) ||
 	(!advanced_tech && can_build)) {
+      production.kind = VUT_IMPROVEMENT;
+      production.value.building = pimprove;
       worklist_id_to_name(pdialog->worklist_avail_names[n],
-			  i, 0, pdialog->pcity);
+			  production, pdialog->pcity);
       pdialog->worklist_avail_names_ptrs[n]=pdialog->worklist_avail_names[n];
-      pdialog->worklist_avail_ids[n++]=i;
+      pdialog->worklist_avail_ids[n++] = improvement_number(pimprove);
     }
-  } impr_type_iterate_end;
+  } improvement_iterate_end;
   pdialog->worklist_avail_num_improvements=n;
 
   /*     + Second, units. */
-  unit_type_iterate(i) {
+  unit_type_iterate(punittype) {
     /* Can the player (eventually) build this improvement? */
-    can_build = can_player_build_unit(pplr,i);
-    can_eventually_build = can_player_eventually_build_unit(pplr,i);
+    can_build = can_player_build_unit_now(client.conn.playing, punittype);
+    can_eventually_build = can_player_build_unit_later(client.conn.playing, punittype);
 
     /* If there's a city, can the city build the improvement? */
     if (pdialog->pcity) {
-      can_build = can_build && can_build_unit(pdialog->pcity, i);
+      can_build = can_build && can_city_build_unit_now(pdialog->pcity, punittype);
       can_eventually_build = can_eventually_build &&
-	can_eventually_build_unit(pdialog->pcity, i);
+	can_city_build_unit_later(pdialog->pcity, punittype);
     }
 
     if (( advanced_tech && can_eventually_build) ||
 	(!advanced_tech && can_build)) {
+      production.kind = VUT_UTYPE;
+      production.value.utype = punittype;
       worklist_id_to_name(pdialog->worklist_avail_names[n],
-			  i, 1, pdialog->pcity);
+			  production, pdialog->pcity);
       pdialog->worklist_avail_names_ptrs[n]=pdialog->worklist_avail_names[n];
-      pdialog->worklist_avail_ids[n++]=i;
+      pdialog->worklist_avail_ids[n++] = utype_number(punittype);
     }
   } unit_type_iterate_end;
 
@@ -1349,13 +1349,14 @@ void worklist_populate_targets(struct worklist_dialog *pdialog)
   /*     + Finally, the global worklists. */
   if (pdialog->pcity) {
     /* Now fill in the global worklists. */
-    for (i = 0; i < MAX_NUM_WORKLISTS; i++)
-      if (pplr->worklists[i].is_valid) {
-	strcpy(pdialog->worklist_avail_names[n], pplr->worklists[i].name);
-	pdialog->worklist_avail_names_ptrs[n]=pdialog->worklist_avail_names[n];
-	pdialog->worklist_avail_ids[n++]=i;
-      }
+    global_worklists_iterate(pgwl) {
+      sz_strlcpy(pdialog->worklist_avail_names[n],
+                 global_worklist_name(pgwl));
+      pdialog->worklist_avail_names_ptrs[n] =
+        pdialog->worklist_avail_names[n];
+      pdialog->worklist_avail_ids[n++] = global_worklist_id(pgwl);
+    } global_worklists_iterate_end;
   }
 
-  pdialog->worklist_avail_names_ptrs[n]=0;
+  pdialog->worklist_avail_names_ptrs[n] = NULL;
 }
