@@ -15,10 +15,13 @@
 
 #include "chatline_common.h"
 
-void real_output_window_append(const char *astring,
-                               const struct text_tag_list *tags,
-                               int conn_id);
-void log_output_window(void);
-void clear_output_window(void);
+#include "gui_proto_constructor.h"
+
+GUI_FUNC_PROTO(void, real_output_window_append, const char *astring,
+               const struct text_tag_list *tags,
+               int conn_id)
+GUI_FUNC_PROTO(void, version_message, char *vertext)
+GUI_FUNC_PROTO(void, log_output_window, void)
+GUI_FUNC_PROTO(void, clear_output_window, void)
 
 #endif  /* FC__CHATLINE_G_H */
