@@ -17,12 +17,14 @@
 
 #include "citydlg_common.h"
 
-void real_city_dialog_popup(struct city *pcity);
-void popdown_city_dialog(struct city *pcity);
-void popdown_all_city_dialogs(void);
-void real_city_dialog_refresh(struct city *pcity);
-void refresh_unit_city_dialogs(struct unit *punit);
-bool city_dialog_is_open(struct city *pcity);
+#include "gui_proto_constructor.h"
+
+GUI_FUNC_PROTO(void, real_city_dialog_popup, struct city *pcity)
+GUI_FUNC_PROTO(void, popdown_city_dialog, struct city *pcity)
+GUI_FUNC_PROTO(void, popdown_all_city_dialogs, void)
+GUI_FUNC_PROTO(void, real_city_dialog_refresh, struct city *pcity)
+GUI_FUNC_PROTO(void, refresh_unit_city_dialogs, struct unit *punit)
+GUI_FUNC_PROTO(bool, city_dialog_is_open, struct city *pcity)
 
 /* Actually defined in update_queue.c */
 void popup_city_dialog(struct city *pcity);
