@@ -35,7 +35,7 @@ GUI_FUNC_PROTO(void, popdown_help_dialog, void)
 #define HELP_WORKLIST_EDITOR_ITEM N_("Worklist Editor")
 #define HELP_CMA_ITEM N_("Citizen Governor")
 #define HELP_CONTROLS_ITEM N_("Controls")
-#define HELP_RULESET_ITEM N_("About Ruleset")
+#define HELP_RULESET_ITEM N_("About Current Ruleset")
 #define HELP_NATIONS_ITEM N_("About Nations")
 #define HELP_ECONOMY_ITEM N_("Economy")
 #define HELP_CITIES_ITEM N_("Cities")
