@@ -13,8 +13,10 @@
 #ifndef FC__MENU_G_H
 #define FC__MENU_G_H
 
-void real_menus_init(void);
-void real_menus_update(void);
+#include "gui_proto_constructor.h"
+
+GUI_FUNC_PROTO(void, real_menus_init, void)
+GUI_FUNC_PROTO(void, real_menus_update, void)
 
 /* Actually defined in update_queue.c */
 void menus_init(void);
