@@ -485,6 +485,19 @@ void calculate_overview_dimensions(void)
   recursion--;
 }
 
+/****************************************************************************
+  Free overview resources.
+****************************************************************************/
+void overview_free(void)
+{
+  if (overview.map) {
+    canvas_free(overview.map);
+    canvas_free(overview.window);
+    overview.map = NULL;
+    overview.window = NULL;
+  }
+}
+
 /****************************************************************************
   Callback to be called when an overview option is changed.
 ****************************************************************************/
