@@ -207,12 +207,26 @@ bool client_handle_packet(enum packet_type type, const void *packet)
       ((const struct packet_diplomacy_accept_treaty *)packet)->other_accepted);
     return TRUE;
 
-  case PACKET_PAGE_MSG:
-    handle_page_msg(
-      ((const struct packet_page_msg *)packet)->caption,
-      ((const struct packet_page_msg *)packet)->headline,
-      ((const struct packet_page_msg *)packet)->lines,
-      ((const struct packet_page_msg *)packet)->event);
+  case PACKET_PAGE_MSG_OLD:
+    handle_page_msg_old(
+      ((const struct packet_page_msg_old *)packet)->caption,
+      ((const struct packet_page_msg_old *)packet)->headline,
+      ((const struct packet_page_msg_old *)packet)->lines,
+      ((const struct packet_page_msg_old *)packet)->event);
+    return TRUE;
+
+  case PACKET_PAGE_MSG_NEW:
+    handle_page_msg_new(
+      ((const struct packet_page_msg_new *)packet)->caption,
+      ((const struct packet_page_msg_new *)packet)->headline,
+      ((const struct packet_page_msg_new *)packet)->event,
+      ((const struct packet_page_msg_new *)packet)->len,
+      ((const struct packet_page_msg_new *)packet)->parts);
+    return TRUE;
+
+  case PACKET_PAGE_MSG_PART:
+    handle_page_msg_part(
+      ((const struct packet_page_msg_part *)packet)->lines);
     return TRUE;
 
   case PACKET_CONN_INFO:
