@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,6 +13,11 @@
 #ifndef FC__CARAVAN_H
 #define FC__CARAVAN_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 /* utility */
 #include "log.h"                /* enum log_level */
 #include "shared.h"
@@ -127,7 +132,7 @@ void caravan_parameter_log_real(const struct caravan_parameter *parameter,
   }
 
 void caravan_result_init_zero(struct caravan_result *result);
-int caravan_result_compare(const struct caravan_result *a, 
+int caravan_result_compare(const struct caravan_result *a,
                            const struct caravan_result *b);
 
 void caravan_evaluate(const struct unit *caravan, const struct city *dest,
@@ -142,4 +147,8 @@ void caravan_optimize_allpairs(const struct unit *caravan,
                                const struct caravan_parameter *parameter,
                                struct caravan_result *result);
 
-#endif
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+  
+#endif /* FC__CARAVAN_H */
