@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 2003 - The Freeciv Project
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,9 +13,14 @@
 #ifndef FC__PF_TOOLS_H
 #define FC__PF_TOOLS_H
 
-#include "path_finding.h"
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
 
 
+/* common/aicore */
+#include "path_finding.h"
+
 /* 
  * Use to create 'amphibious' paths. An amphibious path starts on a sea tile,
  * perhaps goes over some other sea tiles, then perhaps goes over some land
@@ -39,9 +44,9 @@ struct pft_amphibious
 
 
 void pft_fill_unit_parameter(struct pf_parameter *parameter,
-			     const struct unit *punit);
+                             const struct unit *punit);
 void pft_fill_unit_overlap_param(struct pf_parameter *parameter,
-				 const struct unit *punit);
+                                 const struct unit *punit);
 void pft_fill_unit_attack_param(struct pf_parameter *parameter,
                                 const struct unit *punit);
 
@@ -68,4 +73,8 @@ enum tile_behavior no_intermediate_fights(const struct tile *ptile,
                                           enum known_type known,
                                           const struct pf_parameter *param);
 
-#endif				/* FC__PF_TOOLS_H */
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+#endif /* FC__PF_TOOLS_H */
