@@ -61,11 +61,12 @@ bool is_native_base_to_utype(const struct base_type *pbase,
 bool is_native_tile_to_base(const struct base_type *pbase,
                             const struct tile *ptile)
 {
-  /* FIXME: Bases cannot be built in a city currently?  It should be a
-   * a negative requirement in the ruleset. */
-  return (!tile_city(ptile)
-          && are_reqs_active(NULL, NULL, NULL, ptile,
-                             NULL, NULL, NULL, &pbase->reqs, RPT_POSSIBLE));
+  if (tile_city(ptile) != NULL && pbase->border_sq >= 0) {
+    return FALSE;
+  }
+
+  return are_reqs_active(NULL, NULL, NULL, ptile,
+                         NULL, NULL, NULL, &pbase->reqs, RPT_POSSIBLE);
 }
 
 /****************************************************************************
@@ -162,11 +163,11 @@ bool is_base_near_tile(const struct tile *ptile, const struct base_type *pbase)
 /**************************************************************************
   Can unit build base to given tile?
 **************************************************************************/
-bool can_build_base(const struct unit *punit, const struct base_type *pbase,
-                    const struct tile *ptile)
+static bool base_can_be_built(const struct base_type *pbase,
+                              const struct tile *ptile)
 {
-  if (tile_city(ptile)) {
-    /* Bases cannot be built inside cities */
+  if (tile_terrain(ptile)->base_time == 0) {
+    /* Bases cannot be built on this terrain. */
     return FALSE;
   }
 
@@ -180,6 +181,36 @@ bool can_build_base(const struct unit *punit, const struct base_type *pbase,
     return FALSE;
   }
 
+  if (tile_city(ptile) != NULL && pbase->border_sq >= 0) {
+    return FALSE;
+  }
+
+  return TRUE;
+}
+
+/****************************************************************************
+  Tells if player can build base to tile with suitable unit.
+****************************************************************************/
+bool player_can_build_base(const struct base_type *pbase,
+                           const struct player *pplayer,
+                           const struct tile *ptile)
+{
+  if (!base_can_be_built(pbase, ptile)) {
+    return FALSE;
+  }
+  return are_reqs_active(pplayer, NULL, NULL, ptile,
+                         NULL, NULL, NULL, &pbase->reqs, RPT_POSSIBLE);
+}
+
+/**************************************************************************
+  Can unit build base to given tile?
+**************************************************************************/
+bool can_build_base(const struct unit *punit, const struct base_type *pbase,
+                    const struct tile *ptile)
+{
+  if (!base_can_be_built(pbase, ptile)) {
+    return FALSE;
+  }
   return are_reqs_active(unit_owner(punit), NULL, NULL, ptile,
                          unit_type(punit), NULL, NULL, &pbase->reqs,
                          RPT_CERTAIN);
@@ -310,3 +341,11 @@ bool territory_claiming_base(const struct base_type *pbase)
 {
   return pbase->border_sq >= 0;
 }
+
+/**************************************************************************
+  Who owns bases on tile
+**************************************************************************/
+struct player *base_owner(const struct tile *ptile)
+{
+  return tile_owner(ptile);
+}
