@@ -28,6 +28,7 @@ extern "C" {
 #include "improvement.h"
 #include "unitlist.h"
 #include "vision.h"
+#include "workertask.h"
 #include "worklist.h"
 
 enum production_class_type {
@@ -41,14 +42,17 @@ enum production_class_type {
  * toggled by the user.  Each one defaults to off.  Adding new ones
  * will break network compatibility.  Reordering them will break savegame
  * compatibility.  If you want to remove one you should replace it with
- * a CITYO_UNUSED entry; new options can just be added at the end.*/
+ * a CITYO_UNUSED entry; new options can just be added at the end.
+ *
+ * Used in the network protocol.
+ */
 enum city_options {
   CITYO_DISBAND,      /* If building a settler at size 1 disbands the city */
   CITYO_NEW_EINSTEIN, /* If new citizens are science specialists */
   CITYO_NEW_TAXMAN,   /* If new citizens are gold specialists */
   CITYO_LAST
 };
-BV_DEFINE(bv_city_options, CITYO_LAST);
+BV_DEFINE(bv_city_options, CITYO_LAST); /* Used in the network protocol. */
 
 /* Changing the max radius requires updating network capabilities and results
  * in incompatible savefiles. */
@@ -73,11 +77,6 @@ BV_DEFINE(bv_city_options, CITYO_LAST);
 
 #define INCITE_IMPOSSIBLE_COST (1000 * 1000 * 1000)
 
-/*
- * Number of trade routes a city can have.
- */
-#define NUM_TRADE_ROUTES        4
-
 /*
  * Size of the biggest possible city.
  *
@@ -93,6 +92,8 @@ struct iter_index {
   int dx, dy, dist;
 };
 
+/* City map coordinates are positive integers shifted by the maximum
+ * radius the game engine allows (not the current ruleset) */
 #define CITY_REL2ABS(_coor) (_coor + CITY_MAP_MAX_RADIUS)
 #define CITY_ABS2REL(_coor) (_coor - CITY_MAP_MAX_RADIUS)
 
@@ -101,6 +102,7 @@ bool city_tile_index_to_xy(int *city_map_x, int *city_map_y,
 int city_tile_xy_to_index(int city_map_x, int city_map_y,
                           int city_radius_sq);
 
+int rs_max_city_radius_sq(void);
 int city_map_radius_sq_get(const struct city *pcity);
 void city_map_radius_sq_set(struct city *pcity, int radius_sq);
 int city_map_tiles(int city_radius_sq);
@@ -258,6 +260,7 @@ enum citizen_feeling {
   FEELING_BASE,		/* before any of the modifiers below */
   FEELING_LUXURY,	/* after luxury */
   FEELING_EFFECT,	/* after building effects */
+  FEELING_NATIONALITY,  /* after citizen nationality effects */
   FEELING_MARTIAL,	/* after units enforce martial order */
   FEELING_FINAL,	/* after wonders (final result) */
   FEELING_LAST
@@ -313,7 +316,7 @@ struct city {
   citizens *nationality;      /* Nationality of the citizens. */
 
   /* trade routes */
-  int trade[NUM_TRADE_ROUTES], trade_value[NUM_TRADE_ROUTES];
+  int trade[MAX_TRADE_ROUTES], trade_value[MAX_TRADE_ROUTES];
 
   /* Tile output, regardless of if the tile is actually worked. It is used
    * as cache for the output of the tiles within the city map.
@@ -405,6 +408,8 @@ struct city {
       void *ais[FC_AI_LAST];
 
       struct vision *vision;
+
+      struct worker_task task_req;
     } server;
 
     struct {
@@ -413,6 +418,7 @@ struct city {
       bool walls;
       bool happy;
       bool unhappy;
+      int  city_image;
 
       /* The color is an index into the city_colors array in mapview_common */
       bool colored;
@@ -515,6 +521,7 @@ void city_size_set(struct city *pcity, citizens size);
 citizens city_specialists(const struct city *pcity);
 
 citizens player_content_citizens(const struct player *pplayer);
+citizens player_angry_citizens(const struct player *pplayer);
 
 int city_population(const struct city *pcity);
 int city_total_impr_gold_upkeep(const struct city *pcity);
@@ -557,6 +564,7 @@ bool city_can_use_specialist(const struct city *pcity,
 bool city_has_building(const struct city *pcity,
 		       const struct impr_type *pimprove);
 bool is_capital(const struct city *pcity);
+bool is_gov_center(const struct city *pcity);
 bool city_got_citywalls(const struct city *pcity);
 bool city_got_defense_effect(const struct city *pcity,
                              const struct unit_type *attacker);
@@ -624,16 +632,6 @@ bool city_can_be_built_here(const struct tile *ptile,
 enum city_build_result city_build_here_test(const struct tile *ptile,
                                             const struct unit *punit);
 
-/* trade functions */
-bool can_cities_trade(const struct city *pc1, const struct city *pc2);
-bool can_establish_trade_route(const struct city *pc1, const struct city *pc2);
-bool have_cities_trade_route(const struct city *pc1, const struct city *pc2);
-int trade_between_cities(const struct city *pc1, const struct city *pc2);
-int city_num_trade_routes(const struct city *pcity);
-int get_caravan_enter_city_trade_bonus(const struct city *pc1, 
-                                       const struct city *pc2);
-int get_city_min_trade_route(const struct city *pcity, int *slot);
-
 /* list functions */
 struct city *city_list_find_number(struct city_list *This, int id);
 struct city *city_list_find_name(struct city_list *This, const char *name);
@@ -702,6 +700,7 @@ int city_pollution_types(const struct city *pcity, int shield_total,
 int city_pollution(const struct city *pcity, int shield_total);
 int city_illness_calc(const struct city *pcity, int *ill_base,
                       int *ill_size, int *ill_trade, int *ill_pollution);
+bool city_had_recent_plague(const struct city *pcity);
 int city_build_slots(const struct city *pcity);
 int city_airlift_max(const struct city *pcity);
 
