@@ -19,6 +19,7 @@ extern "C" {
 
 #include "support.h"            /* bool type */
 
+/* Used in the network protocol. */
 #define SPECENUM_NAME event_type
 #define SPECENUM_VALUE0   E_CITY_CANTBUILD
 #define SPECENUM_VALUE1   E_CITY_LOST
@@ -143,10 +144,12 @@ extern "C" {
 #define SPECENUM_VALUE108 E_CITY_RADIUS_SQ
 /* A unit with population cost was built; the city shrinks. */
 #define SPECENUM_VALUE109 E_UNIT_BUILT_POP_COST
+#define SPECENUM_VALUE110 E_DISASTER
 /*
  * Note: If you add a new event, make sure you make a similar change
- * to the events array in "common/events.c" using GEN_EV and
- * "data/stdsounds.soundspec"
+ * to the events array in "common/events.c" using GEN_EV, and to
+ * "data/stdsounds.soundspec", which serves as the documentation to
+ * soundset authors.
  */
 #define SPECENUM_COUNT E_COUNT
 /* The sound system also generates "e_game_quit", although there's no
