@@ -192,13 +192,9 @@ struct ruler_title {
 /****************************************************************************
   Hash function.
 ****************************************************************************/
-static genhash_val_t nation_hash_val(const struct nation_type *pnation,
-                                     size_t num_buckets)
+static genhash_val_t nation_hash_val(const struct nation_type *pnation)
 {
-  genhash_val_t base = (NULL != pnation ? nation_number(pnation)
-                        : nation_count());
-
-  return base % num_buckets;
+  return NULL != pnation ? nation_number(pnation) : nation_count();
 }
 
 /****************************************************************************
@@ -214,14 +210,15 @@ static bool nation_hash_comp(const struct nation_type *pnation1,
   Create a new ruler title.
 ****************************************************************************/
 static struct ruler_title *ruler_title_new(const struct nation_type *pnation,
+                                           const char *domain,
                                            const char *ruler_male_title,
                                            const char *ruler_female_title)
 {
   struct ruler_title *pruler_title = fc_malloc(sizeof(*pruler_title));
 
   pruler_title->pnation = pnation;
-  name_set(&pruler_title->male, ruler_male_title);
-  name_set(&pruler_title->female, ruler_female_title);
+  name_set(&pruler_title->male, domain, ruler_male_title);
+  name_set(&pruler_title->female, domain, ruler_female_title);
 
   return pruler_title;
 }
@@ -324,8 +321,14 @@ government_ruler_title_new(struct government *pgovern,
                            const char *ruler_male_title,
                            const char *ruler_female_title)
 {
-  struct ruler_title *pruler_title =
-      ruler_title_new(pnation, ruler_male_title, ruler_female_title);
+  const char *domain = NULL;
+  struct ruler_title *pruler_title;
+
+  if (pnation != NULL) {
+    domain = pnation->translation_domain;
+  }
+  pruler_title =
+    ruler_title_new(pnation, domain, ruler_male_title, ruler_female_title);
 
   if (!ruler_title_check(pruler_title)) {
     ruler_title_destroy(pruler_title);
