@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -733,23 +733,26 @@ bool can_channel_land(const struct tile *ptile)
   the tiles are assumed to be adjacent, and the (x,y)
   values are used only to get the river bonus correct.
 
-  May also be used with punit==NULL, in which case punit
+  May also be used with punit == NULL, in which case punit
   tests are not done (for unit-independent results).
 ***************************************************************/
-static int tile_move_cost_ptrs(const struct unit *punit,
-                               const struct unit_class *pclass,
-                               const struct player *pplayer,
-			       const struct tile *t1, const struct tile *t2)
+int tile_move_cost_ptrs(const struct unit *punit,
+                        const struct unit_class *pclass,
+                        const struct player *pplayer,
+                        const struct tile *t1, const struct tile *t2)
 {
   bool native = TRUE;
   int cost = tile_terrain(t2)->movement_cost * SINGLE_MOVE;
-  bool cardinal_move;
+  bool cardinality_checked = FALSE;
+  bool cardinal_move = FALSE;
   bool ri;
 
-  fc_assert(punit == NULL || pclass == NULL || unit_class(punit) == pclass);
-
   if (punit) {
-    pclass = unit_class(punit);
+    struct unit_class *puclass = unit_class(punit);
+
+    fc_assert(pclass == NULL || puclass == pclass);
+
+    pclass = puclass;
     native = is_native_tile_to_class(pclass, t2);
   }
 
@@ -789,14 +792,19 @@ static int tile_move_cost_ptrs(const struct unit *punit,
    * leaving ships, so UTYF_IGTER check has to be before native terrain
    * check. We want to give railroad bonus only to native units. */
   ri = restrict_infra(pplayer, t1, t2);
-  cardinal_move = (ALL_DIRECTIONS_CARDINAL() || is_move_cardinal(t1, t2));
 
-  road_type_iterate(proad) {
-    if (proad->move_mode != RMM_NO_BONUS
-        && (!ri || road_has_flag(proad, RF_UNRESTRICTED_INFRA))) {
-      if ((!pclass || is_native_road_to_uclass(proad, pclass))
-          && tile_has_road(t1, proad) && tile_has_road(t2, proad)) {
-        if (cost > proad->move_cost) {
+  road_type_list_iterate(pclass->cache.bonus_roads, proad) {
+    if ((!ri || road_has_flag(proad, RF_UNRESTRICTED_INFRA))
+        && tile_has_road(t1, proad) && tile_has_road(t2, proad)) {
+      if (cost > proad->move_cost) {
+
+        if (proad->move_mode == RMM_FAST_ALWAYS) {
+          cost = proad->move_cost;
+        } else {
+          if (!cardinality_checked) {
+            cardinal_move = (ALL_DIRECTIONS_CARDINAL() || is_move_cardinal(t1, t2));
+            cardinality_checked = TRUE;
+          }
           if (cardinal_move) {
             cost = proad->move_cost;
           } else {
@@ -807,16 +815,17 @@ static int tile_move_cost_ptrs(const struct unit *punit,
               if (cost > proad->move_cost * 2) {
                 cardinal_between_iterate(t1, t2, between) {
                   if (tile_has_road(between, proad)) {
-                  /* TODO: Should we restrict this more?
-                   * Should we check against enemy cities on between tile?
-                   * Should we check against non-native terrain on between tile?
-                   */
-                  cost = proad->move_cost * 2;
+                    /* TODO: Should we restrict this more?
+                     * Should we check against enemy cities on between tile?
+                     * Should we check against non-native terrain on between tile?
+                     */
+                    cost = proad->move_cost * 2;
                   }
                 } cardinal_between_iterate_end;
               }
               break;
             case RMM_FAST_ALWAYS:
+              fc_assert(proad->move_mode != RMM_FAST_ALWAYS); /* Already handled above */
               cost = proad->move_cost;
               break;
             case RMM_NO_BONUS:
@@ -827,7 +836,7 @@ static int tile_move_cost_ptrs(const struct unit *punit,
         }
       }
     }
-  } road_type_iterate_end;
+  } road_type_list_iterate_end;
 
   if (punit && unit_has_type_flag(punit, UTYF_IGTER)) {
     return MIN(cost, MOVE_COST_IGTER);
@@ -863,25 +872,6 @@ static bool restrict_infra(const struct player *pplayer, const struct tile *t1,
   return FALSE;
 }
 
-/***************************************************************
-  The cost to move punit from where it is to tile x,y.
-  It is assumed the move is a valid one, e.g. the tiles are adjacent.
-***************************************************************/
-int map_move_cost_unit(struct unit *punit, const struct tile *ptile)
-{
-  return tile_move_cost_ptrs(punit, NULL, unit_owner(punit),
-                             unit_tile(punit), ptile);
-}
-
-/***************************************************************
-  Move cost between two tiles
-***************************************************************/
-int map_move_cost(const struct player *pplayer, const struct unit_class *pclass,
-                  const struct tile *src_tile, const struct tile *dst_tile)
-{
-  return tile_move_cost_ptrs(NULL, pclass, pplayer, src_tile, dst_tile);
-}
-
 /***************************************************************
   Are two tiles adjacent to each other.
 ***************************************************************/
