@@ -59,6 +59,7 @@ static inline void name_init(struct name_translation *ptrans)
   qualifier).
 ****************************************************************************/
 static inline void names_set(struct name_translation *ptrans,
+                             const char *domain,
                              const char *vernacular_name,
                              const char *rule_name)
 {
@@ -68,10 +69,17 @@ static inline void names_set(struct name_translation *ptrans,
   (void) sz_loud_strlcpy(ptrans->rulename,
                          rule_name ? rule_name : Qn_(vernacular_name),
                          name_too_long);
-  /* Translate now. */
-  ptrans->translated =
-    ('\0' == ptrans->vernacular[0]
-     ? ptrans->vernacular : Q_(ptrans->vernacular));
+
+  if (ptrans->vernacular[0] != '\0') {
+    /* Translate now. */
+    if (domain == NULL) {
+      ptrans->translated = Q_(ptrans->vernacular);
+    } else {
+      ptrans->translated = skip_intl_qualifier_prefix(DG_(domain, ptrans->vernacular));
+    }
+  } else {
+    ptrans->translated = ptrans->vernacular;
+  }
 }
 
 /****************************************************************************
@@ -79,9 +87,10 @@ static inline void names_set(struct name_translation *ptrans,
   Assumes the rule name should be based on the vernacular.
 ****************************************************************************/
 static inline void name_set(struct name_translation *ptrans,
+                            const char *domain,
                             const char *vernacular_name)
 {
-  names_set(ptrans, vernacular_name, NULL);
+  names_set(ptrans, domain, vernacular_name, NULL);
 }
 
 /****************************************************************************
