@@ -135,10 +135,13 @@ struct packet_game_info {
   int happy_cost;
   bool happyborders;
   int heating;
+  int illness_base_factor_old;
   int illness_base_factor;
   int illness_min_size;
   bool illness_on;
+  int illness_pollution_factor_old;
   int illness_pollution_factor;
+  int illness_trade_infection_old;
   int illness_trade_infection;
   int init_city_radius_sq;
   bool is_edit_mode;
@@ -1083,6 +1086,7 @@ struct packet_ruleset_unit_class {
   int min_speed_new;
   int hp_loss_pct;
   int hut_behavior;
+  int non_native_def_pct;
   bv_unit_class_flags flags;
 };
 
