@@ -606,15 +606,15 @@ int get_activity_rate_this_turn(const struct unit *punit)
   already done by this unit.
 **************************************************************************/
 int get_turns_for_activity_at(const struct unit *punit,
-			      enum unit_activity activity,
-			      const struct tile *ptile)
+                              enum unit_activity activity,
+                              const struct tile *ptile)
 {
   /* FIXME: This is just an approximation since we don't account for
    * get_activity_rate_this_turn. */
   int speed = get_activity_rate(punit);
   int time = tile_activity_time(activity, ptile);
 
-  if (time >= 0 && speed >= 0) {
+  if (time >= 0 && speed > 0) {
     return (time - 1) / speed + 1; /* round up */
   } else {
     return FC_INFINITY;
