@@ -172,25 +172,6 @@ int utype_happy_cost(const struct unit_type *ut,
   return ut->happy_cost * get_player_bonus(pplayer, EFT_UNHAPPY_FACTOR);
 }
 
-/**************************************************************************
-  Return whether the given unit class has the flag.
-**************************************************************************/
-bool uclass_has_flag(const struct unit_class *punitclass,
-                     enum unit_class_flag_id flag)
-{
-  fc_assert_ret_val(unit_class_flag_id_is_valid(flag), FALSE);
-  return BV_ISSET(punitclass->flags, flag);
-}
-
-/**************************************************************************
-  Return whether the given unit type has the flag.
-**************************************************************************/
-bool utype_has_flag(const struct unit_type *punittype, int flag)
-{
-  fc_assert_ret_val(unit_type_flag_id_is_valid(flag), FALSE);
-  return BV_ISSET(punittype->flags, flag);
-}
-
 /**************************************************************************
   Return whether the unit has the given flag.
 **************************************************************************/
@@ -1149,6 +1130,7 @@ void unit_classes_init(void)
     unit_classes[i].cache.refuel_bases = NULL;
     unit_classes[i].cache.native_tile_bases = NULL;
     unit_classes[i].cache.native_tile_roads = NULL;
+    unit_classes[i].cache.bonus_roads = NULL;
   }
 }
 
@@ -1172,6 +1154,10 @@ void unit_classes_free(void)
       road_type_list_destroy(unit_classes[i].cache.native_tile_roads);
       unit_classes[i].cache.native_tile_roads = NULL;
     }
+    if (unit_classes[i].cache.bonus_roads != NULL) {
+      road_type_list_destroy(unit_classes[i].cache.bonus_roads);
+      unit_classes[i].cache.bonus_roads = NULL;
+    }
   }
 }
 
@@ -1344,6 +1330,7 @@ void set_unit_class_caches(struct unit_class *pclass)
   pclass->cache.refuel_bases = base_type_list_new();
   pclass->cache.native_tile_bases = base_type_list_new();
   pclass->cache.native_tile_roads = road_type_list_new();
+  pclass->cache.bonus_roads = road_type_list_new();
 
   base_type_iterate(pbase) {
     if (is_native_base_to_uclass(pbase, pclass)) {
@@ -1355,9 +1342,13 @@ void set_unit_class_caches(struct unit_class *pclass)
   } base_type_iterate_end;
 
   road_type_iterate(proad) {
-    if (is_native_road_to_uclass(proad, pclass)
-        && road_has_flag(proad, RF_NATIVE_TILE)) {
-      road_type_list_append(pclass->cache.native_tile_roads, proad);
+    if (is_native_road_to_uclass(proad, pclass)) {
+      if (road_has_flag(proad, RF_NATIVE_TILE)) {
+        road_type_list_append(pclass->cache.native_tile_roads, proad);
+      }
+      if (proad->move_mode != RMM_NO_BONUS) {
+        road_type_list_append(pclass->cache.bonus_roads, proad);
+      }
     }
   } road_type_iterate_end;
 }
