@@ -80,6 +80,12 @@ struct ai_type;
 #define SPECENUM_COUNT UCF_COUNT
 #include "specenum_gen.h"
 
+/* The largest distance a ruleset can allow a unit to paradrop.
+ * Remember to make sure that the field type of PACKET_RULESET_UNIT's
+ * paratroopers_range field can transfer the new maximum if you increase
+ * it. */
+#define UNIT_MAX_PARADROP_RANGE 255
+
 /* Used in the network protocol. */
 BV_DEFINE(bv_unit_classes, UCL_LAST);
 BV_DEFINE(bv_unit_class_flags, UCF_COUNT);
@@ -109,6 +115,7 @@ struct unit_class {
     struct base_type_list *refuel_bases;
     struct base_type_list *native_tile_bases;
     struct road_type_list *native_tile_roads;
+    struct road_type_list *bonus_roads;
   } cache;
 };
 
@@ -154,7 +161,7 @@ struct unit_class {
 #define SPECENUM_VALUE10NAME N_("?unitflag:Settlers")
 #define SPECENUM_VALUE11 UTYF_DIPLOMAT
 #define SPECENUM_VALUE11NAME N_("?unitflag:Diplomat")
-/* Trireme sinking effect */
+/* Trireme must stay close to the coast */
 #define SPECENUM_VALUE12 UTYF_TRIREME
 #define SPECENUM_VALUE12NAME N_("?unitflag:Trireme")
 /* Nuclear attack effect */
@@ -431,7 +438,8 @@ struct unit_type {
   int happy_cost;  /* unhappy people in home city */
   int upkeep[O_LAST];
 
-  int paratroopers_range; /* only valid for F_PARATROOPERS */
+  /* Only valid for UTYF_PARATROOPERS */
+  int paratroopers_range;
   int paratroopers_mr_req;
   int paratroopers_mr_sub;
 
@@ -491,7 +499,14 @@ const char *utype_values_translation(const struct unit_type *punittype);
 
 /* General unit type flag and role routines */
 bool unit_has_type_flag(const struct unit *punit, enum unit_type_flag_id flag);
-bool utype_has_flag(const struct unit_type *punittype, int flag);
+
+/**************************************************************************
+  Return whether the given unit type has the flag.
+**************************************************************************/
+static inline bool utype_has_flag(const struct unit_type *punittype, int flag)
+{
+  return BV_ISSET(punittype->flags, flag);
+}
 
 bool unit_has_type_role(const struct unit *punit, enum unit_role_id role);
 bool utype_has_role(const struct unit_type *punittype, int role);
@@ -547,8 +562,14 @@ struct unit_class *unit_class_by_rule_name(const char *s);
 const char *uclass_rule_name(const struct unit_class *pclass);
 const char *uclass_name_translation(const struct unit_class *pclass);
 
-bool uclass_has_flag(const struct unit_class *punitclass,
-                     enum unit_class_flag_id flag);
+/**************************************************************************
+  Return whether the given unit class has the flag.
+**************************************************************************/
+static inline bool uclass_has_flag(const struct unit_class *punitclass,
+                                   enum unit_class_flag_id flag)
+{
+  return BV_ISSET(punitclass->flags, flag);
+}
 
 /* Ancillary routines */
 int unit_build_shield_cost(const struct unit *punit);
