@@ -212,13 +212,13 @@ static void count_my_units(struct player *pplayer)
       adv->stats.units.sea++;
     }
 
-    if (unit_has_type_flag(punit, F_TRIREME)) {
+    if (unit_has_type_flag(punit, UTYF_TRIREME)) {
       adv->stats.units.triremes++;
     }
     if (uclass_has_flag(unit_class(punit), UCF_MISSILE)) {
       adv->stats.units.missiles++;
     }
-    if (unit_has_type_flag(punit, F_PARATROOPERS)) {
+    if (unit_has_type_flag(punit, UTYF_PARATROOPERS)) {
       adv->stats.units.paratroopers++;
     }
     if (can_upgrade_unittype(pplayer, unit_type(punit)) >= 0) {
@@ -267,7 +267,7 @@ bool adv_data_phase_init(struct player *pplayer, bool is_new_phase)
 
   TIMING_LOG(AIT_AIDATA, TIMER_START);
 
-  nuke_units = num_role_units(F_NUCLEAR);
+  nuke_units = num_role_units(UTYF_NUCLEAR);
   danger_of_nukes = FALSE;
 
   /*** Threats ***/
@@ -297,18 +297,23 @@ bool adv_data_phase_init(struct player *pplayer, bool is_new_phase)
     } city_list_iterate_end;
 
     unit_list_iterate(aplayer->units, punit) {
-      if (unit_has_type_flag(punit, F_IGWALL)) {
+      const struct unit_class *pclass = unit_class(punit);
+
+      if (unit_has_type_flag(punit, UTYF_IGWALL)) {
         adv->threats.igwall = TRUE;
       }
 
-      if (is_sailing_unit(punit)) {
+      if (pclass->adv.sea_move != MOVE_NONE) {
         /* If the enemy has not started sailing yet, or we have total
          * control over the seas, don't worry, keep attacking. */
-        if (get_transporter_capacity(punit) > 0) {
-          unit_class_iterate(punitclass) {
-            if (punitclass->move_type == UMT_LAND
-                && can_unit_type_transport(unit_type(punit), punitclass)) {
-              /* Enemy can transport some land units! */
+        if (uclass_has_flag(pclass, UCF_CAN_OCCUPY_CITY)) {
+          /* Enemy represents a cross-continental threat! */
+          adv->threats.invasions = TRUE;
+        } else if (get_transporter_capacity(punit) > 0) {
+          unit_class_iterate(cargoclass) {
+            if (uclass_has_flag(cargoclass, UCF_CAN_OCCUPY_CITY)
+                && can_unit_type_transport(unit_type(punit), cargoclass)) {
+              /* Enemy can transport some threatening units! */
               adv->threats.invasions = TRUE;
               break;
             }
@@ -340,14 +345,14 @@ bool adv_data_phase_init(struct player *pplayer, bool is_new_phase)
       }
 
       /* If he builds nukes, worry a lot. */
-      if (unit_has_type_flag(punit, F_NUCLEAR)) {
+      if (unit_has_type_flag(punit, UTYF_NUCLEAR)) {
         danger_of_nukes = TRUE;
       }
     } unit_list_iterate_end;
 
     /* Check for nuke capability */
     for (i = 0; i < nuke_units; i++) {
-      struct unit_type *nuke = get_role_unit(F_NUCLEAR, i);
+      struct unit_type *nuke = get_role_unit(UTYF_NUCLEAR, i);
 
       if (can_player_build_unit_direct(aplayer, nuke)) { 
         adv->threats.nuclear = 1;
@@ -413,7 +418,7 @@ bool adv_data_phase_init(struct player *pplayer, bool is_new_phase)
   unit_list_iterate(pplayer->units, punit) {
     struct tile *ptile = unit_tile(punit);
 
-    if (!is_ocean_tile(ptile) && unit_has_type_flag(punit, F_SETTLERS)) {
+    if (!is_ocean_tile(ptile) && unit_has_type_flag(punit, UTYF_SETTLERS)) {
       adv->stats.workers[(int)tile_continent(unit_tile(punit))]++;
     }
   } unit_list_iterate_end;
@@ -596,7 +601,7 @@ struct adv_data *adv_data_get(struct player *pplayer, bool *close)
        instead of making intrusive fixes for actual bug in stable branch,
        do not assert for non-debug builds of stable versions. */
 #if defined(DEBUG) || defined(IS_DEVEL_VERSION)
-  fc_assert(close != NULL || adv->phase_is_initialized || game.info.phase_mode != PMT_CONCURRENT);
+  fc_assert(close != NULL || adv->phase_is_initialized);
 #endif
 
   if (close != NULL) {
