@@ -20,6 +20,8 @@
 struct settlermap;
 struct pf_path;
 
+void adv_settlers_free(void);
+
 void auto_settlers_player(struct player *pplayer);
 
 void auto_settler_findwork(struct player *pplayer, 
@@ -32,13 +34,21 @@ void auto_settler_setup_work(struct player *pplayer, struct unit *punit,
                              struct pf_path *path,
                              struct tile *best_tile,
                              enum unit_activity best_act,
+                             struct act_tgt *best_target,
                              int completion_time);
 
 int settler_evaluate_improvements(struct unit *punit,
                                   enum unit_activity *best_act,
+                                  struct act_tgt *best_target,
                                   struct tile **best_tile,
                                   struct pf_path **path,
                                   struct settlermap *state);
+int settler_evaluate_city_requests(struct unit *punit,
+                                   enum unit_activity *best_act,
+                                   struct act_tgt *best_target,
+                                   struct tile **best_tile,
+                                   struct pf_path **path,
+                                   struct settlermap *state);
 
 void adv_unit_new_task(struct unit *punit, enum adv_unit_task task,
                        struct tile *ptile);
@@ -46,4 +56,6 @@ void adv_unit_new_task(struct unit *punit, enum adv_unit_task task,
 bool adv_settler_safe_tile(const struct player *pplayer, struct unit *punit,
                            struct tile *ptile);
 
+int adv_settlers_road_bonus(struct tile *ptile, struct road_type *proad);
+
 #endif   /* FC__AUTOSETTLERS_H */
