@@ -1,4 +1,4 @@
-/**********************************************************************
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -32,6 +32,13 @@
 #include <Dialogs.h>
 #endif
 
+#ifdef HAVE_WINSOCK
+#ifdef HAVE_WINSOCK2
+#include <winsock2.h>
+#else  /* HAVE_WINSOCK2 */
+#include <winsock.h>
+#endif /* HAVE_WINSOCK2 */
+#endif /* HAVE_WINSOCK */
 #ifdef WIN32_NATIVE
 #include <windows.h>
 #endif
@@ -224,14 +231,18 @@ int main(int argc, char *argv[])
 #endif /* NDEBUG */
     } else if ((option = get_option_malloc("--Ranklog", argv, &inx, argc))) {
       srvarg.ranklog_filename = option; /* Never freed. */
+    } else if (is_option("--keep", argv[inx])) {
+      srvarg.metaconnection_persistent = TRUE;
+      /* Implies --meta */
+      srvarg.metaserver_no_send = FALSE;
     } else if (is_option("--nometa", argv[inx])) {
       fc_fprintf(stderr, _("Warning: the %s option is obsolete.  "
-			   "Use -m to enable the metaserver.\n"), argv[inx]);
+                           "Use -m to enable the metaserver.\n"), argv[inx]);
       showhelp = TRUE;
     } else if (is_option("--meta", argv[inx])) {
       srvarg.metaserver_no_send = FALSE;
     } else if ((option = get_option_malloc("--Metaserver",
-					 argv, &inx, argc))) {
+                                           argv, &inx, argc))) {
       sz_strlcpy(srvarg.metaserver_addr, option);
       free(option);
       srvarg.metaserver_no_send = FALSE;      /* --Metaserver implies --meta */
@@ -268,7 +279,7 @@ int main(int argc, char *argv[])
 #ifdef HAVE_FCDB
     } else if ((option = get_option_malloc("--Database", argv, &inx, argc))) {
       srvarg.fcdb_enabled = TRUE;
-      srvarg.fcdb_conf = option;
+      srvarg.fcdb_conf = option; /* Never freed */
     } else if (is_option("--auth", argv[inx])) {
       srvarg.auth_enabled = TRUE;
     } else if (is_option("--Guests", argv[inx])) {
@@ -388,6 +399,9 @@ int main(int argc, char *argv[])
                 /* TRANS: "Metaserver" is exactly what user must type, do not translate. */
                 _("Metaserver ADDR"),
                 _("Set ADDR as metaserver address"));
+    cmdhelp_add(help, "k", "keep",
+                _("Keep updating game information on metaserver even after "
+                  "failure")),
     cmdhelp_add(help, "p",
                 /* TRANS: "port" is exactly what user must type, do not translate. */
                 _("port PORT"),
