@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996-2004 - The Freeciv Project
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -266,7 +266,8 @@ static struct command commands[] = {
    N_("Control metaserver connection."),
    N_("'metaconnection ?' reports on the status of the connection to metaserver. "
       "'metaconnection down' or 'metac d' brings the metaserver connection down. "
-      "'metaconnection up' or 'metac u' brings the metaserver connection up."),
+      "'metaconnection up' or 'metac u' brings the metaserver connection up. "
+      "'metaconnection persistent' or 'metac p' is like 'up', but keeps trying after failures. "),
    NULL,
    CMD_ECHO_ADMINS, VCF_NONE, 0
   },
@@ -444,7 +445,7 @@ static struct command commands[] = {
   {"timeoutincrease", ALLOW_CTRL, 
    /* TRANS: translate text between <> only */
    N_("timeoutincrease <turn> <turninc> <value> <valuemult>"), 
-   N_("See \"help timeoutincrease\"."),
+   N_("See \"/help timeoutincrease\"."),
    N_("Every <turn> turns, add <value> to timeout timer, then add <turninc> "
       "to <turn> and multiply <value> by <valuemult>. Use this command in "
       "concert with the option \"timeout\". Defaults are 0 0 0 1"), NULL,
@@ -456,7 +457,7 @@ static struct command commands[] = {
       "cancelvote <vote number>\n"
       "cancelvote all\n"),
    /* TRANS: "vote" as a process */
-   N_("Cancel a running vote.\n"),
+   N_("Cancel a running vote."),
    /* TRANS: "vote" as a process */
    N_("With no arguments this command removes your own vote. If you have "
       "an admin access level, you can cancel any vote by vote number, or "
