@@ -336,6 +336,12 @@ bool handle_login_request(struct connection *pconn,
   char msg[MAX_LEN_MSG];
   int kick_time_remaining;
 
+  if (pconn->established || pconn->server.status != AS_NOT_ESTABLISHED) {
+    /* We read the PACKET_SERVER_JOIN_REQ twice from this connection,
+     * this is probably not a Freeciv client. */
+    return FALSE;
+  }
+
   log_normal(_("Connection request from %s from %s"),
              req->username, pconn->addr);
 
@@ -411,6 +417,14 @@ bool handle_login_request(struct connection *pconn,
     }
   } conn_list_iterate_end;
 
+  /* Remove the ping timeout given in sernet.c:server_make_connection(). */
+  fc_assert_msg(1 == timer_list_size(pconn->server.ping_timers),
+                "Ping timer list size %d, should be 1. Have we sent "
+                "a ping to unestablished connection %s?",
+                timer_list_size(pconn->server.ping_timers),
+                conn_description(pconn));
+  timer_list_pop_front(pconn->server.ping_timers);
+
   if (game.server.connectmsg[0] != '\0') {
     log_debug("Sending connectmsg: %s", game.server.connectmsg);
     dsend_packet_connect_msg(pconn, game.server.connectmsg);
@@ -561,11 +575,15 @@ static bool connection_attach_real(struct connection *pconn,
       if (NULL == pplayer) {
         /* no uncontrolled player found */
         if (player_count() >= game.server.max_players
-            || player_count() - server.nbarbarians >= server.playable_nations) {
+            || normal_player_count() >= server.playable_nations) {
           return FALSE;
         }
         /* add new player, or not */
+        /* Should only be called in such a way as to create a new player
+         * in the pregame */
+        fc_assert_ret_val(!game_was_started(), FALSE);
         pplayer = server_create_player(-1, default_ai_type_name(), NULL);
+        /* Pregame => no need to assign_player_colors() */
         if (!pplayer) {
           return FALSE;
         }
@@ -587,7 +605,7 @@ static bool connection_attach_real(struct connection *pconn,
         /* Temporarily set player_name() to username. */
         server_player_set_name(pplayer, pconn->username);
       }
-      aifill(game.info.aifill);
+      (void) aifill(game.info.aifill);
     }
 
     if (game.server.auto_ai_toggle && pplayer->ai_controlled) {
@@ -727,7 +745,7 @@ void connection_detach(struct connection *pconn, bool remove_unused_player)
 
         /* Actually do the removal. */
         server_remove_player(pplayer);
-        aifill(game.info.aifill);
+        (void) aifill(game.info.aifill);
         reset_all_start_commands();
       } else {
         /* Aitoggle the player if no longer connected. */
