@@ -107,10 +107,13 @@ void enable_fog_of_war_player(struct player *pplayer);
 void disable_fog_of_war_player(struct player *pplayer);
 
 void map_calculate_borders(void);
-void map_claim_border(struct tile *ptile, struct player *powner);
+void map_claim_border(struct tile *ptile, struct player *powner,
+                      int radius_sq);
 void map_claim_ownership(struct tile *ptile, struct player *powner,
                          struct tile *psource);
 void map_clear_border(struct tile *ptile);
+void map_update_border(struct tile *ptile, struct player *owner,
+                       int old_radius_sq, int new_radius_sq);
 
 void map_claim_base(struct tile *ptile, struct base_type *pbase,
                     struct player *powner, struct player *ploser);
