@@ -1071,7 +1071,7 @@ static bool scan_score_log(char *id)
 {
   int line_nr, turn, plr_no, spaces;
   struct plrdata_slot *plrdata;
-  char plr_name[MAX_LEN_NAME], line[80], *ptr;
+  char plr_name[MAX_LEN_NAME], line[120], *ptr;
 
   fc_assert_ret_val(score_log != NULL, FALSE);
   fc_assert_ret_val(score_log->fp != NULL, FALSE);
@@ -1349,7 +1349,7 @@ void log_civ_score_now(void)
       fprintf(score_log->fp,
               "\n"
               "# For a specification of the format of this see doc/README.scorelog or \n"
-              "# <http://svn.gna.org/viewcvs/freeciv/trunk/doc/README.scorelog?view=auto>.\n"
+              "# <https://raw.githubusercontent.com/freeciv/freeciv/master/doc/README.scorelog>.\n"
               "\n");
 
       fprintf(score_log->fp, "id %s\n", server.game_identifier);
@@ -1504,7 +1504,7 @@ void report_final_scores(struct conn_list *dest)
 
   i = 0;
   players_iterate(pplayer) {
-    if (GOOD_PLAYER(pplayer)) {
+    if (is_barbarian(pplayer) == FALSE) {
       size[i].value = pplayer->score.game;
       size[i].player = pplayer;
       i++;
