@@ -56,7 +56,7 @@ struct sset_val_name {
 /* Levels allow options to be subdivided and thus easier to navigate */
 #define SPECENUM_NAME sset_level
 #define SPECENUM_VALUE0     SSET_NONE
-#define SPECENUM_VALUE0NAME N_("None")
+#define SPECENUM_VALUE0NAME N_("?ssetlevel:None")
 #define SPECENUM_VALUE1     SSET_ALL
 #define SPECENUM_VALUE1NAME N_("All")
 #define SPECENUM_VALUE2     SSET_VITAL
@@ -91,7 +91,7 @@ int setting_number(const struct setting *pset);
 
 const char *setting_name(const struct setting *pset);
 const char *setting_short_help(const struct setting *pset);
-const char *setting_extra_help(const struct setting *pset);
+const char *setting_extra_help(const struct setting *pset, bool constant);
 enum sset_type setting_type(const struct setting *pset);
 enum sset_level setting_level(const struct setting *pset);
 enum sset_category setting_category(const struct setting *pset);
