@@ -13,8 +13,10 @@
 #ifndef FC__UNITHAND_H
 #define FC__UNITHAND_H
 
+/* common */
 #include "unit.h"
 
+/* server */
 #include "hand_gen.h"
 
 void unit_activity_handling(struct unit *punit,
@@ -22,11 +24,15 @@ void unit_activity_handling(struct unit *punit,
 void unit_activity_handling_targeted(struct unit *punit,
                                      enum unit_activity new_activity,
                                      struct act_tgt *new_target);
-void unit_change_homecity_handling(struct unit *punit, struct city *new_pcity);
+void unit_change_homecity_handling(struct unit *punit, struct city *new_pcity,
+                                   bool rehome);
 
 bool unit_move_handling(struct unit *punit, struct tile *pdesttile,
                         bool igzoc, bool move_diplomat_city);
 
+bool unit_build_city(struct player *pplayer, struct unit *punit,
+                     const char *name);
+
 void city_add_or_build_error(struct player *pplayer, struct unit *punit,
                              enum unit_add_build_city_result res);
 
