@@ -3,7 +3,7 @@
 files=`find $1 -name "*.h" \
        | sort \
        | grep -v intl \
-       | grep -v common/spec \
+       | grep -v utility/spec \
        | grep -v "Freeciv\.h" \
        | grep -v \./common/packets_gen\.h \
        | grep -v tolua_.*_gen\.h \
@@ -27,4 +27,4 @@ for file in $files; do
      || (grep ifndef $file >/dev/null \
          && grep ifndef $file /dev/null | head -n1)
 done
-echo
\ No newline at end of file
+echo
