@@ -1,7 +1,7 @@
 #!/bin/sh
 
-echo "# C files which use va_list but don't include stdarg.h:"
-find $1 -name "*.c" \
+echo "# C or C++ files which use va_list but don't include stdarg.h:"
+find $1 -name "*.c" -o -name "*.cpp" \
  | sort \
  | grep -v intl \
  | while read line; do 
