@@ -460,6 +460,7 @@ static bool manual_command(void)
                 : Q_("?tech:None"));
         fprintf(doc, "<td>%s</td>\n</tr>\n\n", buf);
       } improvement_iterate_end;
+      fprintf(doc, "</table>");
       break;
 
     case MANUAL_GOVS:
@@ -510,7 +511,8 @@ int main(int argc, char **argv)
   while (inx < argc) {
     if ((option = get_option_malloc("--ruleset", argv, &inx, argc))) {
       if (ruleset != NULL) {
-        log_error(_("Multiple rulesets requested. Only one ruleset at time supported"));
+        fc_fprintf(stderr, _("Multiple rulesets requested. Only one "
+                             "ruleset at a time is supported.\n"));
         free(option);
       } else {
         ruleset = option;
