@@ -14,7 +14,15 @@
 #ifndef FC__BACKTRACE_H
 #define FC__BACKTRACE_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 void backtrace_init(void);
 void backtrace_deinit(void);
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 #endif /* FC__BACKTRACE_H */
