@@ -25,13 +25,6 @@
 
 #include "genlist.h"
 
-/* A single element of a genlist, storing the pointer to user
- * data, and pointers to the next and previous elements: */
-struct genlist_link {
-  struct genlist_link *next, *prev;
-  void *dataptr;
-};
-
 /****************************************************************************
   Create a new empty genlist.
 ****************************************************************************/
@@ -698,27 +691,3 @@ void genlist_release_mutex(struct genlist *pgenlist)
 {
   fc_release_mutex(&pgenlist->mutex);
 }
-
-/****************************************************************************
-  Returns the pointer of this link.
-****************************************************************************/
-void *genlist_link_data(const struct genlist_link *plink)
-{
-  return (NULL != plink ? plink->dataptr : NULL);
-}
-
-/****************************************************************************
-  Returns the previous link.
-****************************************************************************/
-struct genlist_link *genlist_link_prev(const struct genlist_link *plink)
-{
-  return plink->prev;
-}
-
-/****************************************************************************
-  Returns the next link.
-****************************************************************************/
-struct genlist_link *genlist_link_next(const struct genlist_link *plink)
-{
-  return plink->next;
-}
