@@ -73,6 +73,7 @@
 
 /* utility */
 #include "astring.h"
+#include "fcintl.h"
 #include "ioz.h"
 #include "log.h"
 #include "mem.h"
@@ -477,6 +478,9 @@ static bool read_a_line(struct inputfile *inf)
 
     if (!ret) {
       /* fgets failed */
+      if (pos > 0) {
+        inf_log(inf, LOG_ERROR, _("End-of-file not in line of its own"));
+      }
       inf->at_eof = TRUE;
       if (inf->in_string) {
         /* Note: Don't allow multi-line strings to cross "include"
@@ -798,7 +802,7 @@ static const char *get_token_value(struct inputfile *inf)
       return NULL;
     }
     /* If its a comma, we don't want to obliterate it permanently,
-     * so rememeber it: */
+     * so remember it: */
     trailing = *c;
     *((char *) c) = '\0';       /* Tricky. */
 
