@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,6 +17,10 @@
 
 #include <curl/curl.h>
 
+#ifdef WIN32_NATIVE
+#include <windows.h>
+#endif
+
 /* utility */
 #include "fcintl.h"
 #include "ioz.h"
@@ -31,6 +35,8 @@ struct netfile_post {
   struct curl_httppost *last;
 };
 
+static char error_buf_curl[CURL_ERROR_SIZE];
+
 /********************************************************************** 
   Set handle to usable state.
 ***********************************************************************/
@@ -45,6 +51,9 @@ static CURL *netfile_init_handle(void)
     curl_easy_reset(handle);
   }
 
+  error_buf_curl[0] = '\0';
+  curl_easy_setopt(handle, CURLOPT_ERRORBUFFER, error_buf_curl);
+
   return handle;
 }
 
@@ -58,6 +67,7 @@ static bool netfile_download_file_core(const char *URL, FILE *fp,
   CURLcode curlret;
   struct curl_slist *headers = NULL;
   static CURL *handle;
+  bool ret = TRUE;
 
   handle = netfile_init_handle();
 
@@ -66,6 +76,7 @@ static bool netfile_download_file_core(const char *URL, FILE *fp,
   curl_easy_setopt(handle, CURLOPT_URL, URL);
   curl_easy_setopt(handle, CURLOPT_WRITEDATA, fp);
   curl_easy_setopt(handle, CURLOPT_HTTPHEADER, headers);
+  curl_easy_setopt(handle, CURLOPT_FAILONERROR, 1);
 
   curlret = curl_easy_perform(handle);
 
@@ -73,17 +84,20 @@ static bool netfile_download_file_core(const char *URL, FILE *fp,
 
   if (curlret != CURLE_OK) {
     if (cb != NULL) {
-      char buf[2048];
+      char buf[2048 + CURL_ERROR_SIZE];
 
       fc_snprintf(buf, sizeof(buf),
-                  _("Failed to fetch %s"), URL);
+                  /* TRANS: first %s is URL, second is Curl error message
+                   * (not in Freeciv translation domain) */
+                  _("Failed to fetch %s: %s"), URL,
+                  error_buf_curl[0] != '\0' ? error_buf_curl : curl_easy_strerror(curlret));
       cb(buf, data);
     }
 
-    return FALSE;
+    ret = FALSE;
   }
 
-  return TRUE;
+  return ret;
 }
 
 /********************************************************************** 
