@@ -40,12 +40,24 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+
+/* Must be before <windows.h> */
+#ifdef HAVE_WINSOCK
+#ifdef HAVE_WINSOCK2
+#include <winsock2.h>
+#else  /* HAVE_WINSOCK2 */
+#include <winsock.h>
+#endif /* HAVE_WINSOCK2 */
+#endif /* HAVE_WINSOCK */
+
 #ifdef WIN32_NATIVE
 #include <windows.h>
 #include <lmcons.h>	/* UNLEN */
 #include <shlobj.h>
+#ifdef HAVE_DIRECT_H
 #include <direct.h>
-#endif
+#endif /* HAVE_DIRECT_H */
+#endif /* WIN32_NATIVE */
 
 /* utility */
 #include "astring.h"
@@ -1444,12 +1456,7 @@ char *get_langname(void)
       case LANG_DUTCH:
         return "nl";
       case LANG_NORWEGIAN:
-        switch (SUBLANGID(GetUserDefaultLangID())) {
-          case SUBLANG_NORWEGIAN_BOKMAL:
-            return "nb";
-          default:
-            return "no";
-        }
+        return "nb";
       case LANG_POLISH:
         return "pl";
       case LANG_PORTUGUESE:
